//
//      bigtext - print big text using X11 fonts
//      Copyright (C) 2004, 2007, 2010 Peter Miller
//
//      This program is free software; you can redistribute it and/or modify
//      it under the terms of the GNU General Public License as published by
//      the Free Software Foundation; either version 3 of the License, or
//      (at your option) any later version.
//
//      This program is distributed in the hope that it will be useful,
//      but WITHOUT ANY WARRANTY; without even the implied warranty of
//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//      GNU General Public License for more details.
//
//      You should have received a copy of the GNU General Public License
//      along with this program. If not, see
//      <http://www.gnu.org/licenses/>.
//

#ifndef BIGTEXT_CANVAS_H
#define BIGTEXT_CANVAS_H

#include <bigtext/canvas/row.h>

/**
  * The canvas class is used to represent a drawable bitmap of infinite
  * size.  Areas not set to black are implicitly white.  The text is
  * drawn into a canvas before it is written out.
  */
class canvas
{
public:
    /**
      * The destructor.
      */
    virtual ~canvas();

    /**
      * The default constructor.
      */
    canvas();

    /**
      * The set method is used to set the pixel at the given coordinates
      * to black.
      */
    virtual void set(int x, int y, char c = '#') = 0;

    /**
      * The get method is used to obtain the value of the pixel at the
      * given coordinates.  If the coordinates are beyond the image
      * boundary, space (' ') will be returned.
      */
    virtual int get(int x, int y) = 0;

    /**
      * The print method is used to write the canvas to the standard output.
      */
    virtual void print() const = 0;

private:
    /**
      * The copy constructor.   Do not use.
      */
    canvas(const canvas &);

    /**
      * The assignment operator.   Do not use.
      */
    canvas &operator=(const canvas &);
};

#endif // BIGTEXT_CANVAS_H
