//
//      bigtext - print big text using X11 fonts
//      Copyright (C) 2004, 2007, 2010 Peter Miller
//
//      This program is free software; you can redistribute it and/or modify
//      it under the terms of the GNU General Public License as published by
//      the Free Software Foundation; either version 3 of the License, or
//      (at your option) any later version.
//
//      This program is distributed in the hope that it will be useful,
//      but WITHOUT ANY WARRANTY; without even the implied warranty of
//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//      GNU General Public License for more details.
//
//      You should have received a copy of the GNU General Public License
//      along with this program. If not, see
//      <http://www.gnu.org/licenses/>.
//

#ifndef BIGTEXT_CANVAS_ROW_H
#define BIGTEXT_CANVAS_ROW_H

/**
  * The canvas_row class is used to represent a single row of the
  * drawable bitmap.  The row is of infinite width.  Areas not set to
  * black are implicitly white (zero).
  */
class canvas_row
{
public:
    /**
      * The destructor.
      */
    virtual ~canvas_row();

    /**
      * The default constructor.
      */
    canvas_row();

    /**
      * The set method is used to set the pixel at the given
      * column to black.
      */
    void set(int x, char c = '#');

    /**
      * The get method is used to get the pixel at the given column to
      * black.  If beyond row limits, space (' ') is returned.
      */
    int get(int x);

    /**
      * The print method is used to write the row to the standard
      * output.
      */
    void print(int left, int right) const;

    /**
      * The limits method is used to calculate the left and right limits
      * of the whole canvas.
      */
    void limits(int &left, int &right) const;

private:
    /**
      * The resize method is used to increase the size of the array
      * being used to hold the row data.
      */
    void resize(int new_col_min, int new_col_max);

    /**
      * The col_min instance variable is use to remember the minimum
      * x-axis extent.
      */
    int col_min;

    /**
      * The col_max instance variable is use to remember the maximum
      * x-axis extent.
      */
    int col_max;

    /**
      * The col instance variable is use to remember the characters
      * from which the row is composed.
      */
    unsigned char *col;

    /**
      * The copy constructor.   Do not use.
      */
    canvas_row(const canvas_row &);

    /**
      * The assignment operator.   Do not use.
      */
    canvas_row &operator=(const canvas_row &);
};

#endif // BIGTEXT_CANVAS_ROW_H
