//
// bigtext - print big text using X11 fonts
// Copyright (C) 2006-2008, 2010 Peter Miller
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
//

#include <cassert>
#include <cmath>

#include <bigtext/canvas/scale.h>


#if 0
#define DEBUG(fmt, args...) \
    fprintf(stderr, "%s: %d: " fmt, __FILE__, __LINE__ , ##args)
#else
#define DEBUG(fmt, args...) \
    ((void)0)
#endif


canvas_scale::~canvas_scale()
{
}


canvas_scale::canvas_scale(canvas *a_deeper, double a_sx, double a_sy) :
    deeper(a_deeper),
    sx(a_sx),
    sy(a_sy)
{
}


void
canvas_scale::set(int x, int y, char c)
{
    DEBUG("set(x = %d, y = %d, c = '%c')\n", x, y, c);
    for (int dx = 0; dx < sx; ++dx)
    {
        for (int dy = 0; dy < sy; ++dy)
        {
            DEBUG("deeper->set(%d, %d, '%c')\n",
                int(floor(0.5 + x * sx + dx)),
                int(floor(0.5 + y * sy + dy)),
                c
            );
            deeper->set
            (
                int(floor(0.5 + x * sx + dx)),
                int(floor(0.5 + y * sy + dy)),
                c
            );
        }
    }
}


int
canvas_scale::get(int ox, int oy)
{
    DEBUG("get(ox = %d, oy = %d)\n", ox, oy);
    char c = 0;
    double sum = 0;
    for (double x = ox * sx; x < (ox + 1) * sx; x = floor(x + 1))
    {
        //DEBUG("x = %g\n", x);
        double x_max = (ox + 1) * sx;
        if (x_max > floor(x + 1))
            x_max = floor(x + 1);
        //DEBUG("x_max = %g\n", x_max);
        double x_frac = x_max - x;
        //DEBUG("x_frac = %g\n", x_frac);
        for (double y = oy * sy; y < (oy + 1) * sy; y = floor(y + 1))
        {
            //DEBUG("y = %g\n", y);
            double y_max = (oy + 1) * sy;
            if (y_max > floor(y + 1))
                y_max = floor(y + 1);
            //DEBUG("y_max = %g\n", y_max);
            double y_frac = y_max - y;
            //DEBUG("y_frac = %g\n", y_frac);

            int dc = deeper->get(int(floor(x)), int(floor(y)));
            DEBUG
            (
                "deeper->get(%d, %d) -> '%c'\n",
                int(floor(x)),
                int(floor(y)),
                dc
            );
            if (dc != ' ')
            {
                if (c == 0)
                    c = dc;
                sum += x_frac * y_frac;
            }
        }
    }
    DEBUG("sum = %g/%g\n", sum, sx * sy);
    char rc = ' ';
    if (2 * sum >= sx * sy)
        rc = '*';
    else if (4 * sum > sx * sy)
        rc = '.';
    DEBUG("return '%c'\n", rc);
    return rc;
}


void
canvas_scale::print()
    const
{
    deeper->print();
}
