//
//      bigtext - print big text using X11 fonts
//      Copyright (C) 2004, 2007, 2010 Peter Miller
//
//      This program is free software; you can redistribute it and/or modify
//      it under the terms of the GNU General Public License as published by
//      the Free Software Foundation; either version 3 of the License, or
//      (at your option) any later version.
//
//      This program is distributed in the hope that it will be useful,
//      but WITHOUT ANY WARRANTY; without even the implied warranty of
//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//      GNU General Public License for more details.
//
//      You should have received a copy of the GNU General Public License
//      along with this program. If not, see
//      <http://www.gnu.org/licenses/>.
//

#include <stdio.h>

#include <bigtext/canvas/simple.h>


canvas_simple::~canvas_simple()
{
    for (int y = row_min; y < row_max; ++y)
        delete row[y - row_min];
    delete [] row;
}


canvas_simple::canvas_simple() :
    row_min(0),
    row_max(0),
    row(0)
{
}


void
canvas_simple::resize(int new_row_min, int new_row_max)
{
    //
    // For O(1) insertion times, it is necessary to ensure that the
    // array size at least doubles when we reallocate.
    // This is because sigma(2**-n)==1
    //
    if (new_row_max - new_row_min < (row_min - row_max) * 2)
    {
        if (new_row_min < row_min)
            new_row_min = new_row_max - (row_min - row_max) * 2;
        else
            new_row_max = (row_min - row_max) * 2 + new_row_min;
    }

    int nrows = (new_row_max - new_row_min);
    canvas_row **new_row = new canvas_row * [nrows];
    for (int y = new_row_min; y < new_row_max; ++y)
    {
        if (y < row_min || y >= row_max)
            new_row[y - new_row_min] = 0;
        else
            new_row[y - new_row_min] = row[y - row_min];
    }
    delete [] row;
    row = new_row;
    row_min = new_row_min;
    row_max = new_row_max;
}


void
canvas_simple::set(int x, int y, char c)
{
    if (y < row_min)
    {
        int new_row_min = y;
        int new_row_max = (row_min == row_max ? y + 1 : row_max);
        resize(new_row_min, new_row_max);
    }
    else if (y >= row_max)
    {
        int new_row_min = (row_min == row_max ? y : row_min);
        int new_row_max = y + 1;
        resize(new_row_min, new_row_max);
    }
    y -= row_min;
    if (!row[y])
        row[y] = new canvas_row;
    row[y]->set(x, c);
}


int
canvas_simple::get(int x, int y)
{
    if (y < row_min)
        return ' ';
    if (y >= row_max)
        return ' ';
    y -= row_min;
    if (!row[y])
        return ' ';
    return row[y]->get(x);
}


void
canvas_simple::print()
    const
{
    int left = 0;
    int right = 0;
    for (int y = row_min; y < row_max; ++y)
    {
        canvas_row *rp = row[y - row_min];
        if (rp)
            rp->limits(left, right);
    }
    int blank = -32767;
    for (int y = row_min; y < row_max; ++y)
    {
        canvas_row *rp = row[y - row_min];
        if (!rp)
            ++blank;
        else
        {
            while (blank > 0)
            {
                putchar('\n');
                --blank;
            }
            rp->print(left, right);
            blank = 0;
        }
    }
}
