//
//      bigtext - print big text using X11 fonts
//      Copyright (C) 2004, 2007, 2010 Peter Miller
//
//      This program is free software; you can redistribute it and/or modify
//      it under the terms of the GNU General Public License as published by
//      the Free Software Foundation; either version 3 of the License, or
//      (at your option) any later version.
//
//      This program is distributed in the hope that it will be useful,
//      but WITHOUT ANY WARRANTY; without even the implied warranty of
//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//      GNU General Public License for more details.
//
//      You should have received a copy of the GNU General Public License
//      along with this program. If not, see
//      <http://www.gnu.org/licenses/>.
//

#ifndef BIGTEXT_CANVAS_SIMPLE_H
#define BIGTEXT_CANVAS_SIMPLE_H

#include <bigtext/canvas.h>
#include <bigtext/canvas/row.h>

/**
  * The canvas_simple class is used to represent a drawable bitmap of
  * infinite size.  Areas not set to black are implicitly white.  The
  * text is drawn into a canvas before it is written out.
  */
class canvas_simple:
    public canvas
{
public:
    /**
      * The destructor.
      */
    virtual ~canvas_simple();

    /**
      * The default constructor.
      */
    canvas_simple();

    // See base class for documentation.
    void set(int, int, char);

    // See base class for documentation.
    int get(int, int);

    // See base class for documentation.
    void print() const;

private:
    /**
      * The resize method is used to increase the size of the array
      * being used to hold the canvas data.
      */
    void resize(int new_col_min, int new_col_max);

    /**
      * The col_min instance variable is use to remember the minimum
      * y-axis extent.
      */
    int row_min;

    /**
      * The col_max instance variable is use to remember the maximum
      * y-axis extent.
      */
    int row_max;

    /**
      * The row instance variable is use to remember the rows
      * from which the canvas is composed.
      */
    canvas_row **row;

    /**
      * The copy constructor.  Do not use.
      */
    canvas_simple(const canvas_simple &);

    /**
      * The assignment operator.  Do not use.
      */
    canvas_simple &operator=(const canvas_simple &);
};

#endif // BIGTEXT_CANVAS_SIMPLE_H
