//
//      bigtext - print big text using X11 fonts
//      Copyright (C) 2004, 2007, 2010 Peter Miller
//
//      This program is free software; you can redistribute it and/or modify
//      it under the terms of the GNU General Public License as published by
//      the Free Software Foundation; either version 3 of the License, or
//      (at your option) any later version.
//
//      This program is distributed in the hope that it will be useful,
//      but WITHOUT ANY WARRANTY; without even the implied warranty of
//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//      GNU General Public License for more details.
//
//      You should have received a copy of the GNU General Public License
//      along with this program. If not, see
//      <http://www.gnu.org/licenses/>.
//

#include <bigtext/font/internal/fixed.h>
#include <bigtext/glyph/internal.h>

static glyph_internal::info_t table[] =
{
    {
                // 00
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\250"
        "\000"
        "\210"
        "\000"
        "\210"
        "\000"
        "\210"
        "\000"
        "\250"
    },
    {
                // 01
        0,      // left bearing
        5,      // right bearing
        7,      // ascent
        -2,     // descent
        7,      // width
        "\040"
        "\160"
        "\370"
        "\160"
        "\040"
    },
    {
                // 02
        0,      // left bearing
        6,      // right bearing
        11,     // ascent
        2,      // descent
        7,      // width
        "\250"
        "\124"
        "\250"
        "\124"
        "\250"
        "\124"
        "\250"
        "\124"
        "\250"
        "\124"
        "\250"
        "\124"
        "\250"
    },
    {
                // 03
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\240"
        "\240"
        "\340"
        "\240"
        "\240"
        "\070"
        "\020"
        "\020"
        "\020"
    },
    {
                // 04
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\340"
        "\200"
        "\300"
        "\200"
        "\270"
        "\040"
        "\060"
        "\040"
        "\040"
    },
    {
                // 05
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\140"
        "\200"
        "\200"
        "\140"
        "\060"
        "\050"
        "\060"
        "\050"
        "\050"
    },
    {
                // 06
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\200"
        "\200"
        "\200"
        "\340"
        "\070"
        "\040"
        "\060"
        "\040"
        "\040"
    },
    {
                // 07
        1,      // left bearing
        5,      // right bearing
        9,      // ascent
        -5,     // descent
        7,      // width
        "\140"
        "\220"
        "\220"
        "\140"
    },
    {
                // 08
        0,      // left bearing
        5,      // right bearing
        8,      // ascent
        -1,     // descent
        7,      // width
        "\040"
        "\040"
        "\370"
        "\040"
        "\040"
        "\000"
        "\370"
    },
    {
                // 09
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\220"
        "\320"
        "\260"
        "\220"
        "\040"
        "\040"
        "\040"
        "\040"
        "\070"
    },
    {
                // 0A
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\240"
        "\240"
        "\240"
        "\100"
        "\100"
        "\070"
        "\020"
        "\020"
        "\020"
    },
    {
                // 0B
        0,      // left bearing
        3,      // right bearing
        11,     // ascent
        -4,     // descent
        7,      // width
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
        "\340"
    },
    {
                // 0C
        0,      // left bearing
        3,      // right bearing
        5,      // ascent
        2,      // descent
        7,      // width
        "\340"
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
    },
    {
                // 0D
        2,      // left bearing
        6,      // right bearing
        5,      // ascent
        2,      // descent
        7,      // width
        "\360"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
    },
    {
                // 0E
        2,      // left bearing
        6,      // right bearing
        11,     // ascent
        -4,     // descent
        7,      // width
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\360"
    },
    {
                // 0F
        0,      // left bearing
        6,      // right bearing
        11,     // ascent
        2,      // descent
        7,      // width
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
        "\374"
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
    },
    {
                // 10
        0,      // left bearing
        6,      // right bearing
        11,     // ascent
        -10,    // descent
        7,      // width
        "\374"
    },
    {
                // 11
        0,      // left bearing
        6,      // right bearing
        8,      // ascent
        -7,     // descent
        7,      // width
        "\374"
    },
    {
                // 12
        0,      // left bearing
        6,      // right bearing
        5,      // ascent
        -4,     // descent
        7,      // width
        "\374"
    },
    {
                // 13
        0,      // left bearing
        6,      // right bearing
        2,      // ascent
        -1,     // descent
        7,      // width
        "\374"
    },
    {
                // 14
        0,      // left bearing
        6,      // right bearing
        -1,     // ascent
        2,      // descent
        7,      // width
        "\374"
    },
    {
                // 15
        2,      // left bearing
        6,      // right bearing
        11,     // ascent
        2,      // descent
        7,      // width
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\360"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
    },
    {
                // 16
        0,      // left bearing
        3,      // right bearing
        11,     // ascent
        2,      // descent
        7,      // width
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
        "\340"
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
    },
    {
                // 17
        0,      // left bearing
        6,      // right bearing
        11,     // ascent
        -4,     // descent
        7,      // width
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
        "\374"
    },
    {
                // 18
        0,      // left bearing
        6,      // right bearing
        5,      // ascent
        2,      // descent
        7,      // width
        "\374"
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
    },
    {
                // 19
        2,      // left bearing
        3,      // right bearing
        11,     // ascent
        2,      // descent
        7,      // width
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
    },
    {
                // 1A
        0,      // left bearing
        5,      // right bearing
        8,      // ascent
        -1,     // descent
        7,      // width
        "\030"
        "\140"
        "\200"
        "\140"
        "\030"
        "\000"
        "\370"
    },
    {
                // 1B
        0,      // left bearing
        5,      // right bearing
        8,      // ascent
        -1,     // descent
        7,      // width
        "\300"
        "\060"
        "\010"
        "\060"
        "\300"
        "\000"
        "\370"
    },
    {
                // 1C
        0,      // left bearing
        5,      // right bearing
        6,      // ascent
        0,      // descent
        7,      // width
        "\370"
        "\120"
        "\120"
        "\120"
        "\120"
        "\120"
    },
    {
                // 1D
        0,      // left bearing
        5,      // right bearing
        6,      // ascent
        -1,     // descent
        7,      // width
        "\010"
        "\370"
        "\040"
        "\370"
        "\200"
    },
    {
                // 1E
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\060"
        "\110"
        "\100"
        "\100"
        "\340"
        "\100"
        "\100"
        "\110"
        "\260"
    },
    {
                // 1F
        2,      // left bearing
        4,      // right bearing
        5,      // ascent
        -4,     // descent
        7,      // width
        "\300"
    },
    {
                // 20 ' '
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        7,      // width
    },
    {
                // 21 '!'
        2,      // left bearing
        3,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\000"
        "\200"
    },
    {
                // 22 '"'
        1,      // left bearing
        4,      // right bearing
        9,      // ascent
        -6,     // descent
        7,      // width
        "\240"
        "\240"
        "\240"
    },
    {
                // 23 '#'
        0,      // left bearing
        5,      // right bearing
        8,      // ascent
        -1,     // descent
        7,      // width
        "\120"
        "\120"
        "\370"
        "\120"
        "\370"
        "\120"
        "\120"
    },
    {
                // 24 '$'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\040"
        "\170"
        "\240"
        "\240"
        "\160"
        "\050"
        "\050"
        "\360"
        "\040"
    },
    {
                // 25 '%'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\110"
        "\250"
        "\120"
        "\020"
        "\040"
        "\100"
        "\120"
        "\250"
        "\220"
    },
    {
                // 26 '&'
        0,      // left bearing
        5,      // right bearing
        8,      // ascent
        0,      // descent
        7,      // width
        "\100"
        "\240"
        "\240"
        "\100"
        "\240"
        "\230"
        "\220"
        "\150"
    },
    {
                // 27 '''
        2,      // left bearing
        3,      // right bearing
        9,      // ascent
        -6,     // descent
        7,      // width
        "\200"
        "\200"
        "\200"
    },
    {
                // 28 '('
        1,      // left bearing
        4,      // right bearing
        10,     // ascent
        1,      // descent
        7,      // width
        "\040"
        "\100"
        "\100"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\100"
        "\100"
        "\040"
    },
    {
                // 29 ')'
        1,      // left bearing
        4,      // right bearing
        10,     // ascent
        1,      // descent
        7,      // width
        "\200"
        "\100"
        "\100"
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
        "\100"
        "\100"
        "\200"
    },
    {
                // 2A '*'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        -4,     // descent
        7,      // width
        "\040"
        "\250"
        "\160"
        "\250"
        "\040"
    },
    {
                // 2B '+'
        0,      // left bearing
        5,      // right bearing
        7,      // ascent
        -2,     // descent
        7,      // width
        "\040"
        "\040"
        "\370"
        "\040"
        "\040"
    },
    {
                // 2C ','
        1,      // left bearing
        4,      // right bearing
        2,      // ascent
        1,      // descent
        7,      // width
        "\140"
        "\100"
        "\200"
    },
    {
                // 2D '-'
        0,      // left bearing
        5,      // right bearing
        5,      // ascent
        -4,     // descent
        7,      // width
        "\370"
    },
    {
                // 2E '.'
        1,      // left bearing
        4,      // right bearing
        2,      // ascent
        1,      // descent
        7,      // width
        "\100"
        "\340"
        "\100"
    },
    {
                // 2F '/'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\010"
        "\010"
        "\020"
        "\020"
        "\040"
        "\100"
        "\100"
        "\200"
        "\200"
    },
    {
                // 30 '0'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\040"
        "\120"
        "\210"
        "\210"
        "\210"
        "\210"
        "\210"
        "\120"
        "\040"
    },
    {
                // 31 '1'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\040"
        "\140"
        "\240"
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
        "\370"
    },
    {
                // 32 '2'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\160"
        "\210"
        "\210"
        "\010"
        "\020"
        "\040"
        "\100"
        "\200"
        "\370"
    },
    {
                // 33 '3'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\370"
        "\010"
        "\020"
        "\040"
        "\160"
        "\010"
        "\010"
        "\210"
        "\160"
    },
    {
                // 34 '4'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\020"
        "\020"
        "\060"
        "\120"
        "\120"
        "\220"
        "\370"
        "\020"
        "\020"
    },
    {
                // 35 '5'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\370"
        "\200"
        "\200"
        "\260"
        "\310"
        "\010"
        "\010"
        "\210"
        "\160"
    },
    {
                // 36 '6'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\160"
        "\210"
        "\200"
        "\200"
        "\360"
        "\210"
        "\210"
        "\210"
        "\160"
    },
    {
                // 37 '7'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\370"
        "\010"
        "\020"
        "\020"
        "\040"
        "\040"
        "\100"
        "\100"
        "\100"
    },
    {
                // 38 '8'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\160"
        "\210"
        "\210"
        "\210"
        "\160"
        "\210"
        "\210"
        "\210"
        "\160"
    },
    {
                // 39 '9'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\160"
        "\210"
        "\210"
        "\210"
        "\170"
        "\010"
        "\010"
        "\210"
        "\160"
    },
    {
                // 3A ':'
        1,      // left bearing
        4,      // right bearing
        7,      // ascent
        1,      // descent
        7,      // width
        "\100"
        "\340"
        "\100"
        "\000"
        "\000"
        "\100"
        "\340"
        "\100"
    },
    {
                // 3B ';'
        1,      // left bearing
        4,      // right bearing
        7,      // ascent
        1,      // descent
        7,      // width
        "\100"
        "\340"
        "\100"
        "\000"
        "\000"
        "\140"
        "\100"
        "\200"
    },
    {
                // 3C '<'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\010"
        "\020"
        "\040"
        "\100"
        "\200"
        "\100"
        "\040"
        "\020"
        "\010"
    },
    {
                // 3D '='
        0,      // left bearing
        5,      // right bearing
        6,      // ascent
        -2,     // descent
        7,      // width
        "\370"
        "\000"
        "\000"
        "\370"
    },
    {
                // 3E '>'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\200"
        "\100"
        "\040"
        "\020"
        "\010"
        "\020"
        "\040"
        "\100"
        "\200"
    },
    {
                // 3F '?'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\160"
        "\210"
        "\210"
        "\010"
        "\020"
        "\040"
        "\040"
        "\000"
        "\040"
    },
    {
                // 40 '@'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\160"
        "\210"
        "\210"
        "\230"
        "\250"
        "\250"
        "\260"
        "\200"
        "\170"
    },
    {
                // 41 'A'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\040"
        "\120"
        "\210"
        "\210"
        "\210"
        "\370"
        "\210"
        "\210"
        "\210"
    },
    {
                // 42 'B'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\360"
        "\110"
        "\110"
        "\110"
        "\160"
        "\110"
        "\110"
        "\110"
        "\360"
    },
    {
                // 43 'C'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\160"
        "\210"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\210"
        "\160"
    },
    {
                // 44 'D'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\360"
        "\110"
        "\110"
        "\110"
        "\110"
        "\110"
        "\110"
        "\110"
        "\360"
    },
    {
                // 45 'E'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\370"
        "\200"
        "\200"
        "\200"
        "\360"
        "\200"
        "\200"
        "\200"
        "\370"
    },
    {
                // 46 'F'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\370"
        "\200"
        "\200"
        "\200"
        "\360"
        "\200"
        "\200"
        "\200"
        "\200"
    },
    {
                // 47 'G'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\160"
        "\210"
        "\200"
        "\200"
        "\200"
        "\230"
        "\210"
        "\210"
        "\160"
    },
    {
                // 48 'H'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\210"
        "\210"
        "\210"
        "\210"
        "\370"
        "\210"
        "\210"
        "\210"
        "\210"
    },
    {
                // 49 'I'
        1,      // left bearing
        4,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\340"
        "\100"
        "\100"
        "\100"
        "\100"
        "\100"
        "\100"
        "\100"
        "\340"
    },
    {
                // 4A 'J'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\070"
        "\020"
        "\020"
        "\020"
        "\020"
        "\020"
        "\020"
        "\220"
        "\140"
    },
    {
                // 4B 'K'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\210"
        "\210"
        "\220"
        "\240"
        "\300"
        "\240"
        "\220"
        "\210"
        "\210"
    },
    {
                // 4C 'L'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\370"
    },
    {
                // 4D 'M'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\210"
        "\210"
        "\330"
        "\250"
        "\250"
        "\210"
        "\210"
        "\210"
        "\210"
    },
    {
                // 4E 'N'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\210"
        "\310"
        "\310"
        "\250"
        "\250"
        "\230"
        "\230"
        "\210"
        "\210"
    },
    {
                // 4F 'O'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\160"
        "\210"
        "\210"
        "\210"
        "\210"
        "\210"
        "\210"
        "\210"
        "\160"
    },
    {
                // 50 'P'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\360"
        "\210"
        "\210"
        "\210"
        "\360"
        "\200"
        "\200"
        "\200"
        "\200"
    },
    {
                // 51 'Q'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        1,      // descent
        7,      // width
        "\160"
        "\210"
        "\210"
        "\210"
        "\210"
        "\210"
        "\210"
        "\250"
        "\160"
        "\010"
    },
    {
                // 52 'R'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\360"
        "\210"
        "\210"
        "\210"
        "\360"
        "\240"
        "\220"
        "\210"
        "\210"
    },
    {
                // 53 'S'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\160"
        "\210"
        "\200"
        "\200"
        "\160"
        "\010"
        "\010"
        "\210"
        "\160"
    },
    {
                // 54 'T'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\370"
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
    },
    {
                // 55 'U'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\210"
        "\210"
        "\210"
        "\210"
        "\210"
        "\210"
        "\210"
        "\210"
        "\160"
    },
    {
                // 56 'V'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\210"
        "\210"
        "\210"
        "\210"
        "\120"
        "\120"
        "\120"
        "\040"
        "\040"
    },
    {
                // 57 'W'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\210"
        "\210"
        "\210"
        "\210"
        "\250"
        "\250"
        "\250"
        "\250"
        "\120"
    },
    {
                // 58 'X'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\210"
        "\210"
        "\120"
        "\120"
        "\040"
        "\120"
        "\120"
        "\210"
        "\210"
    },
    {
                // 59 'Y'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\210"
        "\210"
        "\120"
        "\120"
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
    },
    {
                // 5A 'Z'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\370"
        "\010"
        "\020"
        "\020"
        "\040"
        "\100"
        "\100"
        "\200"
        "\370"
    },
    {
                // 5B '['
        1,      // left bearing
        4,      // right bearing
        10,     // ascent
        1,      // descent
        7,      // width
        "\340"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\340"
    },
    {
                // 5C '\'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\200"
        "\200"
        "\100"
        "\100"
        "\040"
        "\020"
        "\020"
        "\010"
        "\010"
    },
    {
                // 5D ']'
        1,      // left bearing
        4,      // right bearing
        10,     // ascent
        1,      // descent
        7,      // width
        "\340"
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
        "\040"
        "\340"
    },
    {
                // 5E '^'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        -6,     // descent
        7,      // width
        "\040"
        "\120"
        "\210"
    },
    {
                // 5F '_'
        0,      // left bearing
        5,      // right bearing
        0,      // ascent
        1,      // descent
        7,      // width
        "\370"
    },
    {
                // 60 '`'
        2,      // left bearing
        4,      // right bearing
        10,     // ascent
        -8,     // descent
        7,      // width
        "\200"
        "\100"
    },
    {
                // 61 'a'
        0,      // left bearing
        5,      // right bearing
        6,      // ascent
        0,      // descent
        7,      // width
        "\160"
        "\010"
        "\170"
        "\210"
        "\230"
        "\150"
    },
    {
                // 62 'b'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\200"
        "\200"
        "\200"
        "\360"
        "\210"
        "\210"
        "\210"
        "\210"
        "\360"
    },
    {
                // 63 'c'
        0,      // left bearing
        5,      // right bearing
        6,      // ascent
        0,      // descent
        7,      // width
        "\160"
        "\210"
        "\200"
        "\200"
        "\210"
        "\160"
    },
    {
                // 64 'd'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\010"
        "\010"
        "\010"
        "\170"
        "\210"
        "\210"
        "\210"
        "\210"
        "\170"
    },
    {
                // 65 'e'
        0,      // left bearing
        5,      // right bearing
        6,      // ascent
        0,      // descent
        7,      // width
        "\160"
        "\210"
        "\370"
        "\200"
        "\210"
        "\160"
    },
    {
                // 66 'f'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\060"
        "\110"
        "\100"
        "\100"
        "\360"
        "\100"
        "\100"
        "\100"
        "\100"
    },
    {
                // 67 'g'
        0,      // left bearing
        5,      // right bearing
        6,      // ascent
        2,      // descent
        7,      // width
        "\160"
        "\210"
        "\210"
        "\210"
        "\170"
        "\010"
        "\210"
        "\160"
    },
    {
                // 68 'h'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\200"
        "\200"
        "\200"
        "\260"
        "\310"
        "\210"
        "\210"
        "\210"
        "\210"
    },
    {
                // 69 'i'
        1,      // left bearing
        4,      // right bearing
        8,      // ascent
        0,      // descent
        7,      // width
        "\100"
        "\000"
        "\300"
        "\100"
        "\100"
        "\100"
        "\100"
        "\340"
    },
    {
                // 6A 'j'
        0,      // left bearing
        4,      // right bearing
        8,      // ascent
        2,      // descent
        7,      // width
        "\020"
        "\000"
        "\060"
        "\020"
        "\020"
        "\020"
        "\020"
        "\220"
        "\220"
        "\140"
    },
    {
                // 6B 'k'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\200"
        "\200"
        "\200"
        "\220"
        "\240"
        "\300"
        "\240"
        "\220"
        "\210"
    },
    {
                // 6C 'l'
        1,      // left bearing
        4,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\300"
        "\100"
        "\100"
        "\100"
        "\100"
        "\100"
        "\100"
        "\100"
        "\340"
    },
    {
                // 6D 'm'
        0,      // left bearing
        5,      // right bearing
        6,      // ascent
        0,      // descent
        7,      // width
        "\320"
        "\250"
        "\250"
        "\250"
        "\250"
        "\210"
    },
    {
                // 6E 'n'
        0,      // left bearing
        5,      // right bearing
        6,      // ascent
        0,      // descent
        7,      // width
        "\260"
        "\310"
        "\210"
        "\210"
        "\210"
        "\210"
    },
    {
                // 6F 'o'
        0,      // left bearing
        5,      // right bearing
        6,      // ascent
        0,      // descent
        7,      // width
        "\160"
        "\210"
        "\210"
        "\210"
        "\210"
        "\160"
    },
    {
                // 70 'p'
        0,      // left bearing
        5,      // right bearing
        6,      // ascent
        2,      // descent
        7,      // width
        "\360"
        "\210"
        "\210"
        "\210"
        "\360"
        "\200"
        "\200"
        "\200"
    },
    {
                // 71 'q'
        0,      // left bearing
        5,      // right bearing
        6,      // ascent
        2,      // descent
        7,      // width
        "\170"
        "\210"
        "\210"
        "\210"
        "\170"
        "\010"
        "\010"
        "\010"
    },
    {
                // 72 'r'
        0,      // left bearing
        5,      // right bearing
        6,      // ascent
        0,      // descent
        7,      // width
        "\260"
        "\310"
        "\200"
        "\200"
        "\200"
        "\200"
    },
    {
                // 73 's'
        0,      // left bearing
        5,      // right bearing
        6,      // ascent
        0,      // descent
        7,      // width
        "\160"
        "\210"
        "\140"
        "\020"
        "\210"
        "\160"
    },
    {
                // 74 't'
        0,      // left bearing
        5,      // right bearing
        8,      // ascent
        0,      // descent
        7,      // width
        "\100"
        "\100"
        "\360"
        "\100"
        "\100"
        "\100"
        "\110"
        "\060"
    },
    {
                // 75 'u'
        0,      // left bearing
        5,      // right bearing
        6,      // ascent
        0,      // descent
        7,      // width
        "\210"
        "\210"
        "\210"
        "\210"
        "\230"
        "\150"
    },
    {
                // 76 'v'
        0,      // left bearing
        5,      // right bearing
        6,      // ascent
        0,      // descent
        7,      // width
        "\210"
        "\210"
        "\210"
        "\120"
        "\120"
        "\040"
    },
    {
                // 77 'w'
        0,      // left bearing
        5,      // right bearing
        6,      // ascent
        0,      // descent
        7,      // width
        "\210"
        "\210"
        "\250"
        "\250"
        "\250"
        "\120"
    },
    {
                // 78 'x'
        0,      // left bearing
        5,      // right bearing
        6,      // ascent
        0,      // descent
        7,      // width
        "\210"
        "\120"
        "\040"
        "\040"
        "\120"
        "\210"
    },
    {
                // 79 'y'
        0,      // left bearing
        5,      // right bearing
        6,      // ascent
        2,      // descent
        7,      // width
        "\210"
        "\210"
        "\210"
        "\230"
        "\150"
        "\010"
        "\210"
        "\160"
    },
    {
                // 7A 'z'
        0,      // left bearing
        5,      // right bearing
        6,      // ascent
        0,      // descent
        7,      // width
        "\370"
        "\020"
        "\040"
        "\100"
        "\200"
        "\370"
    },
    {
                // 7B '{'
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        1,      // descent
        7,      // width
        "\030"
        "\040"
        "\040"
        "\040"
        "\040"
        "\300"
        "\040"
        "\040"
        "\040"
        "\040"
        "\030"
    },
    {
                // 7C '|'
        2,      // left bearing
        3,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
    },
    {
                // 7D '}'
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        1,      // descent
        7,      // width
        "\300"
        "\040"
        "\040"
        "\040"
        "\040"
        "\030"
        "\040"
        "\040"
        "\040"
        "\040"
        "\300"
    },
    {
                // 7E '~'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        -6,     // descent
        7,      // width
        "\110"
        "\250"
        "\220"
    },
    {
                // 7F
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 80
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 81
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 82
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 83
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 84
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 85
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 86
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 87
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 88
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 89
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 8A
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 8B
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 8C
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 8D
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 8E
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 8F
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 90
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 91
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 92
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 93
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 94
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 95
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 96
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 97
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 98
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 99
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 9A
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 9B
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 9C
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 9D
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 9E
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 9F
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // A0
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        7,      // width
    },
    {
                // A1
        2,      // left bearing
        3,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\200"
        "\000"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
    },
    {
                // A2
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        -1,     // descent
        7,      // width
        "\040"
        "\160"
        "\250"
        "\240"
        "\240"
        "\250"
        "\160"
        "\040"
    },
    {
                // A3
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\060"
        "\110"
        "\100"
        "\100"
        "\340"
        "\100"
        "\100"
        "\110"
        "\260"
    },
    {
                // A4
        0,      // left bearing
        5,      // right bearing
        7,      // ascent
        -1,     // descent
        7,      // width
        "\210"
        "\160"
        "\120"
        "\120"
        "\160"
        "\210"
    },
    {
                // A5
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\210"
        "\210"
        "\120"
        "\120"
        "\370"
        "\040"
        "\370"
        "\040"
        "\040"
    },
    {
                // A6
        2,      // left bearing
        3,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\200"
        "\200"
        "\200"
        "\200"
        "\000"
        "\200"
        "\200"
        "\200"
        "\200"
    },
    {
                // A7
        1,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\140"
        "\220"
        "\200"
        "\140"
        "\220"
        "\220"
        "\140"
        "\020"
        "\220"
        "\140"
    },
    {
                // A8
        1,      // left bearing
        4,      // right bearing
        10,     // ascent
        -8,     // descent
        7,      // width
        "\240"
        "\240"
    },
    {
                // A9
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        -1,     // descent
        7,      // width
        "\160"
        "\210"
        "\250"
        "\330"
        "\310"
        "\330"
        "\250"
        "\210"
        "\160"
    },
    {
                // AA
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        -2,     // descent
        7,      // width
        "\160"
        "\010"
        "\170"
        "\210"
        "\170"
        "\000"
        "\370"
    },
    {
                // AB
        0,      // left bearing
        5,      // right bearing
        7,      // ascent
        -1,     // descent
        7,      // width
        "\050"
        "\120"
        "\240"
        "\240"
        "\120"
        "\050"
    },
    {
                // AC
        0,      // left bearing
        5,      // right bearing
        5,      // ascent
        -2,     // descent
        7,      // width
        "\370"
        "\010"
        "\010"
    },
    {
                // AD
        1,      // left bearing
        4,      // right bearing
        5,      // ascent
        -4,     // descent
        7,      // width
        "\340"
    },
    {
                // AE
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        -1,     // descent
        7,      // width
        "\160"
        "\210"
        "\350"
        "\330"
        "\330"
        "\350"
        "\330"
        "\210"
        "\160"
    },
    {
                // AF
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        -8,     // descent
        7,      // width
        "\370"
    },
    {
                // B0
        1,      // left bearing
        5,      // right bearing
        9,      // ascent
        -5,     // descent
        7,      // width
        "\140"
        "\220"
        "\220"
        "\140"
    },
    {
                // B1
        0,      // left bearing
        5,      // right bearing
        8,      // ascent
        -1,     // descent
        7,      // width
        "\040"
        "\040"
        "\370"
        "\040"
        "\040"
        "\000"
        "\370"
    },
    {
                // B2
        0,      // left bearing
        3,      // right bearing
        10,     // ascent
        -5,     // descent
        7,      // width
        "\100"
        "\240"
        "\040"
        "\100"
        "\340"
    },
    {
                // B3
        0,      // left bearing
        3,      // right bearing
        10,     // ascent
        -5,     // descent
        7,      // width
        "\100"
        "\240"
        "\100"
        "\040"
        "\300"
    },
    {
                // B4
        2,      // left bearing
        4,      // right bearing
        10,     // ascent
        -8,     // descent
        7,      // width
        "\100"
        "\200"
    },
    {
                // B5
        0,      // left bearing
        5,      // right bearing
        6,      // ascent
        2,      // descent
        7,      // width
        "\210"
        "\210"
        "\210"
        "\210"
        "\230"
        "\350"
        "\200"
        "\200"
    },
    {
                // B6
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\170"
        "\350"
        "\350"
        "\350"
        "\350"
        "\150"
        "\050"
        "\050"
        "\050"
    },
    {
                // B7
        2,      // left bearing
        4,      // right bearing
        5,      // ascent
        -4,     // descent
        7,      // width
        "\300"
    },
    {
                // B8
        2,      // left bearing
        4,      // right bearing
        0,      // ascent
        2,      // descent
        7,      // width
        "\100"
        "\200"
    },
    {
                // B9
        0,      // left bearing
        3,      // right bearing
        10,     // ascent
        -5,     // descent
        7,      // width
        "\100"
        "\300"
        "\100"
        "\100"
        "\340"
    },
    {
                // BA
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        -2,     // descent
        7,      // width
        "\160"
        "\210"
        "\210"
        "\210"
        "\160"
        "\000"
        "\370"
    },
    {
                // BB
        0,      // left bearing
        5,      // right bearing
        7,      // ascent
        -1,     // descent
        7,      // width
        "\240"
        "\120"
        "\050"
        "\050"
        "\120"
        "\240"
    },
    {
                // BC
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\100"
        "\300"
        "\100"
        "\100"
        "\340"
        "\010"
        "\030"
        "\050"
        "\070"
        "\010"
    },
    {
                // BD
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\100"
        "\300"
        "\100"
        "\100"
        "\340"
        "\020"
        "\050"
        "\010"
        "\020"
        "\070"
    },
    {
                // BE
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\100"
        "\240"
        "\100"
        "\040"
        "\240"
        "\110"
        "\030"
        "\050"
        "\070"
        "\010"
    },
    {
                // BF
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\040"
        "\000"
        "\040"
        "\040"
        "\100"
        "\200"
        "\210"
        "\210"
        "\160"
    },
    {
                // C0
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\100"
        "\040"
        "\000"
        "\040"
        "\120"
        "\210"
        "\210"
        "\370"
        "\210"
        "\210"
    },
    {
                // C1
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\020"
        "\040"
        "\000"
        "\040"
        "\120"
        "\210"
        "\210"
        "\370"
        "\210"
        "\210"
    },
    {
                // C2
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\060"
        "\110"
        "\000"
        "\040"
        "\120"
        "\210"
        "\210"
        "\370"
        "\210"
        "\210"
    },
    {
                // C3
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\050"
        "\120"
        "\000"
        "\040"
        "\120"
        "\210"
        "\210"
        "\370"
        "\210"
        "\210"
    },
    {
                // C4
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\120"
        "\120"
        "\000"
        "\040"
        "\120"
        "\210"
        "\210"
        "\370"
        "\210"
        "\210"
    },
    {
                // C5
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\040"
        "\120"
        "\040"
        "\040"
        "\120"
        "\210"
        "\210"
        "\370"
        "\210"
        "\210"
    },
    {
                // C6
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\130"
        "\240"
        "\240"
        "\240"
        "\260"
        "\340"
        "\240"
        "\240"
        "\270"
    },
    {
                // C7
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        2,      // descent
        7,      // width
        "\160"
        "\210"
        "\200"
        "\200"
        "\200"
        "\200"
        "\200"
        "\210"
        "\160"
        "\040"
        "\100"
    },
    {
                // C8
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\100"
        "\040"
        "\000"
        "\370"
        "\200"
        "\200"
        "\360"
        "\200"
        "\200"
        "\370"
    },
    {
                // C9
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\020"
        "\040"
        "\000"
        "\370"
        "\200"
        "\200"
        "\360"
        "\200"
        "\200"
        "\370"
    },
    {
                // CA
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\060"
        "\110"
        "\000"
        "\370"
        "\200"
        "\200"
        "\360"
        "\200"
        "\200"
        "\370"
    },
    {
                // CB
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\120"
        "\120"
        "\000"
        "\370"
        "\200"
        "\200"
        "\360"
        "\200"
        "\200"
        "\370"
    },
    {
                // CC
        1,      // left bearing
        4,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\200"
        "\100"
        "\000"
        "\340"
        "\100"
        "\100"
        "\100"
        "\100"
        "\100"
        "\340"
    },
    {
                // CD
        1,      // left bearing
        4,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\040"
        "\100"
        "\000"
        "\340"
        "\100"
        "\100"
        "\100"
        "\100"
        "\100"
        "\340"
    },
    {
                // CE
        1,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\140"
        "\220"
        "\000"
        "\340"
        "\100"
        "\100"
        "\100"
        "\100"
        "\100"
        "\340"
    },
    {
                // CF
        1,      // left bearing
        4,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\240"
        "\240"
        "\000"
        "\340"
        "\100"
        "\100"
        "\100"
        "\100"
        "\100"
        "\340"
    },
    {
                // D0
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\360"
        "\110"
        "\110"
        "\110"
        "\350"
        "\110"
        "\110"
        "\110"
        "\360"
    },
    {
                // D1
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\050"
        "\120"
        "\000"
        "\210"
        "\210"
        "\310"
        "\250"
        "\230"
        "\210"
        "\210"
    },
    {
                // D2
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\100"
        "\040"
        "\000"
        "\160"
        "\210"
        "\210"
        "\210"
        "\210"
        "\210"
        "\160"
    },
    {
                // D3
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\020"
        "\040"
        "\000"
        "\160"
        "\210"
        "\210"
        "\210"
        "\210"
        "\210"
        "\160"
    },
    {
                // D4
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\060"
        "\110"
        "\000"
        "\160"
        "\210"
        "\210"
        "\210"
        "\210"
        "\210"
        "\160"
    },
    {
                // D5
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\050"
        "\120"
        "\000"
        "\160"
        "\210"
        "\210"
        "\210"
        "\210"
        "\210"
        "\160"
    },
    {
                // D6
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\120"
        "\120"
        "\000"
        "\160"
        "\210"
        "\210"
        "\210"
        "\210"
        "\210"
        "\160"
    },
    {
                // D7
        0,      // left bearing
        5,      // right bearing
        6,      // ascent
        -1,     // descent
        7,      // width
        "\210"
        "\120"
        "\040"
        "\120"
        "\210"
    },
    {
                // D8
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        1,      // descent
        7,      // width
        "\010"
        "\160"
        "\230"
        "\230"
        "\250"
        "\250"
        "\250"
        "\310"
        "\310"
        "\160"
        "\200"
    },
    {
                // D9
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\100"
        "\040"
        "\000"
        "\210"
        "\210"
        "\210"
        "\210"
        "\210"
        "\210"
        "\160"
    },
    {
                // DA
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\020"
        "\040"
        "\000"
        "\210"
        "\210"
        "\210"
        "\210"
        "\210"
        "\210"
        "\160"
    },
    {
                // DB
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\060"
        "\110"
        "\000"
        "\210"
        "\210"
        "\210"
        "\210"
        "\210"
        "\210"
        "\160"
    },
    {
                // DC
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\120"
        "\120"
        "\000"
        "\210"
        "\210"
        "\210"
        "\210"
        "\210"
        "\210"
        "\160"
    },
    {
                // DD
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\020"
        "\040"
        "\000"
        "\210"
        "\210"
        "\120"
        "\040"
        "\040"
        "\040"
        "\040"
    },
    {
                // DE
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\200"
        "\360"
        "\210"
        "\210"
        "\210"
        "\360"
        "\200"
        "\200"
        "\200"
    },
    {
                // DF
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\140"
        "\220"
        "\220"
        "\240"
        "\240"
        "\220"
        "\210"
        "\210"
        "\260"
    },
    {
                // E0
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\100"
        "\040"
        "\000"
        "\160"
        "\010"
        "\170"
        "\210"
        "\230"
        "\150"
    },
    {
                // E1
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\020"
        "\040"
        "\000"
        "\160"
        "\010"
        "\170"
        "\210"
        "\230"
        "\150"
    },
    {
                // E2
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\060"
        "\110"
        "\000"
        "\160"
        "\010"
        "\170"
        "\210"
        "\230"
        "\150"
    },
    {
                // E3
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\050"
        "\120"
        "\000"
        "\160"
        "\010"
        "\170"
        "\210"
        "\230"
        "\150"
    },
    {
                // E4
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\120"
        "\120"
        "\000"
        "\160"
        "\010"
        "\170"
        "\210"
        "\230"
        "\150"
    },
    {
                // E5
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\060"
        "\110"
        "\060"
        "\000"
        "\160"
        "\010"
        "\170"
        "\210"
        "\230"
        "\150"
    },
    {
                // E6
        0,      // left bearing
        5,      // right bearing
        6,      // ascent
        0,      // descent
        7,      // width
        "\160"
        "\050"
        "\160"
        "\240"
        "\250"
        "\120"
    },
    {
                // E7
        0,      // left bearing
        5,      // right bearing
        6,      // ascent
        2,      // descent
        7,      // width
        "\160"
        "\210"
        "\200"
        "\200"
        "\210"
        "\160"
        "\040"
        "\100"
    },
    {
                // E8
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\100"
        "\040"
        "\000"
        "\160"
        "\210"
        "\370"
        "\200"
        "\210"
        "\160"
    },
    {
                // E9
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\020"
        "\040"
        "\000"
        "\160"
        "\210"
        "\370"
        "\200"
        "\210"
        "\160"
    },
    {
                // EA
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\060"
        "\110"
        "\000"
        "\160"
        "\210"
        "\370"
        "\200"
        "\210"
        "\160"
    },
    {
                // EB
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\120"
        "\120"
        "\000"
        "\160"
        "\210"
        "\370"
        "\200"
        "\210"
        "\160"
    },
    {
                // EC
        1,      // left bearing
        4,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\200"
        "\100"
        "\000"
        "\300"
        "\100"
        "\100"
        "\100"
        "\100"
        "\340"
    },
    {
                // ED
        1,      // left bearing
        4,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\040"
        "\100"
        "\000"
        "\300"
        "\100"
        "\100"
        "\100"
        "\100"
        "\340"
    },
    {
                // EE
        1,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\140"
        "\220"
        "\000"
        "\300"
        "\100"
        "\100"
        "\100"
        "\100"
        "\340"
    },
    {
                // EF
        1,      // left bearing
        4,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\240"
        "\240"
        "\000"
        "\300"
        "\100"
        "\100"
        "\100"
        "\100"
        "\340"
    },
    {
                // F0
        0,      // left bearing
        5,      // right bearing
        10,     // ascent
        0,      // descent
        7,      // width
        "\120"
        "\040"
        "\140"
        "\020"
        "\160"
        "\210"
        "\210"
        "\210"
        "\210"
        "\160"
    },
    {
                // F1
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\050"
        "\120"
        "\000"
        "\260"
        "\310"
        "\210"
        "\210"
        "\210"
        "\210"
    },
    {
                // F2
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\100"
        "\040"
        "\000"
        "\160"
        "\210"
        "\210"
        "\210"
        "\210"
        "\160"
    },
    {
                // F3
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\020"
        "\040"
        "\000"
        "\160"
        "\210"
        "\210"
        "\210"
        "\210"
        "\160"
    },
    {
                // F4
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\060"
        "\110"
        "\000"
        "\160"
        "\210"
        "\210"
        "\210"
        "\210"
        "\160"
    },
    {
                // F5
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\050"
        "\120"
        "\000"
        "\160"
        "\210"
        "\210"
        "\210"
        "\210"
        "\160"
    },
    {
                // F6
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\120"
        "\120"
        "\000"
        "\160"
        "\210"
        "\210"
        "\210"
        "\210"
        "\160"
    },
    {
                // F7
        0,      // left bearing
        5,      // right bearing
        8,      // ascent
        -1,     // descent
        7,      // width
        "\040"
        "\040"
        "\000"
        "\370"
        "\000"
        "\040"
        "\040"
    },
    {
                // F8
        0,      // left bearing
        5,      // right bearing
        7,      // ascent
        1,      // descent
        7,      // width
        "\010"
        "\160"
        "\230"
        "\250"
        "\250"
        "\310"
        "\160"
        "\200"
    },
    {
                // F9
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\100"
        "\040"
        "\000"
        "\210"
        "\210"
        "\210"
        "\210"
        "\230"
        "\150"
    },
    {
                // FA
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\020"
        "\040"
        "\000"
        "\210"
        "\210"
        "\210"
        "\210"
        "\230"
        "\150"
    },
    {
                // FB
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\060"
        "\110"
        "\000"
        "\210"
        "\210"
        "\210"
        "\210"
        "\230"
        "\150"
    },
    {
                // FC
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        7,      // width
        "\120"
        "\120"
        "\000"
        "\210"
        "\210"
        "\210"
        "\210"
        "\230"
        "\150"
    },
    {
                // FD
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        2,      // descent
        7,      // width
        "\020"
        "\040"
        "\000"
        "\210"
        "\210"
        "\210"
        "\230"
        "\150"
        "\010"
        "\210"
        "\160"
    },
    {
                // FE
        0,      // left bearing
        5,      // right bearing
        8,      // ascent
        2,      // descent
        7,      // width
        "\200"
        "\200"
        "\260"
        "\310"
        "\210"
        "\210"
        "\310"
        "\260"
        "\200"
        "\200"
    },
    {
                // FF
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        2,      // descent
        7,      // width
        "\120"
        "\120"
        "\000"
        "\210"
        "\210"
        "\210"
        "\230"
        "\150"
        "\010"
        "\210"
        "\160"
    },
};

font_internal_fixed::~font_internal_fixed()
{
    if (glyph_ptr)
    {
        for (int j = 0; j < 256; ++j)
            delete glyph_ptr[j];
        delete [] glyph_ptr;
    }
}

font_internal_fixed::font_internal_fixed() :
    glyph_ptr(0)
{
}

glyph *
font_internal_fixed::get_glyph(unsigned n)
{
    if (n > 256)
        n = '?';
    if (!glyph_ptr)
    {
        glyph_ptr = new glyph * [256];
        for (unsigned j = 0; j < 256; ++j)
            glyph_ptr[j] = 0;
    }
    if (!glyph_ptr[n])
        glyph_ptr[n] = new glyph_internal(table[n]);
    return glyph_ptr[n];
}

int
font_internal_fixed::get_ascent()
{
    return 11;
}

int
font_internal_fixed::get_descent()
{
    return 2;
}

const char *
font_internal_fixed::get_name()
    const
{
    return "fixed";
}
