//
//      bigtext - print big text using X11 fonts
//      Copyright (C) 2004, 2007, 2010 Peter Miller
//
//      This program is free software; you can redistribute it and/or modify
//      it under the terms of the GNU General Public License as published by
//      the Free Software Foundation; either version 3 of the License, or
//      (at your option) any later version.
//
//      This program is distributed in the hope that it will be useful,
//      but WITHOUT ANY WARRANTY; without even the implied warranty of
//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//      GNU General Public License for more details.
//
//      You should have received a copy of the GNU General Public License
//      along with this program. If not, see
//      <http://www.gnu.org/licenses/>.
//

#include <bigtext/font/internal/variable.h>
#include <bigtext/glyph/internal.h>

static glyph_internal::info_t table[] =
{
    {
                // 00
        1,      // left bearing
        8,      // right bearing
        9,      // ascent
        0,      // descent
        10,     // width
        "\252"
        "\000"
        "\202"
        "\000"
        "\202"
        "\000"
        "\202"
        "\000"
        "\252"
    },
    {
                // 01
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 02
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 03
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 04
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 05
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 06
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 07
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 08
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 09
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 0A
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 0B
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 0C
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 0D
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 0E
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 0F
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 10
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 11
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 12
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 13
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 14
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 15
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 16
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 17
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 18
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 19
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 1A
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 1B
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 1C
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 1D
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 1E
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 1F
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 20 ' '
        0,      // left bearing
        1,      // right bearing
        1,      // ascent
        0,      // descent
        5,      // width
        "\000"
    },
    {
                // 21 '!'
        1,      // left bearing
        3,      // right bearing
        9,      // ascent
        0,      // descent
        5,      // width
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\200"
        "\000"
        "\300"
        "\300"
    },
    {
                // 22 '"'
        1,      // left bearing
        4,      // right bearing
        9,      // ascent
        -6,     // descent
        6,      // width
        "\240"
        "\240"
        "\240"
    },
    {
                // 23 '#'
        0,      // left bearing
        7,      // right bearing
        8,      // ascent
        0,      // descent
        9,      // width
        "\024"
        "\024"
        "\176"
        "\050"
        "\050"
        "\374"
        "\120"
        "\120"
    },
    {
                // 24 '$'
        0,      // left bearing
        6,      // right bearing
        9,      // ascent
        2,      // descent
        8,      // width
        "\020"
        "\170"
        "\324"
        "\320"
        "\170"
        "\034"
        "\224"
        "\324"
        "\170"
        "\020"
        "\020"
    },
    {
                // 25 '%'
        0,      // left bearing
        11,     // right bearing
        9,      // ascent
        0,      // descent
        13,     // width
        "\161\000"
        "\333\000"
        "\332\000"
        "\164\000"
        "\004\000"
        "\011\300"
        "\013\140"
        "\033\140"
        "\021\300"
    },
    {
                // 26 '&'
        0,      // left bearing
        9,      // right bearing
        9,      // ascent
        0,      // descent
        10,     // width
        "\070\000"
        "\154\000"
        "\154\000"
        "\070\000"
        "\171\000"
        "\317\000"
        "\306\000"
        "\317\000"
        "\171\200"
    },
    {
                // 27 '''
        1,      // left bearing
        2,      // right bearing
        9,      // ascent
        -6,     // descent
        4,      // width
        "\200"
        "\200"
        "\200"
    },
    {
                // 28 '('
        1,      // left bearing
        5,      // right bearing
        9,      // ascent
        3,      // descent
        7,      // width
        "\060"
        "\140"
        "\140"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\140"
        "\140"
        "\060"
    },
    {
                // 29 ')'
        1,      // left bearing
        5,      // right bearing
        9,      // ascent
        3,      // descent
        7,      // width
        "\300"
        "\140"
        "\140"
        "\060"
        "\060"
        "\060"
        "\060"
        "\060"
        "\060"
        "\140"
        "\140"
        "\300"
    },
    {
                // 2A '*'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        -5,     // descent
        7,      // width
        "\040"
        "\370"
        "\160"
        "\120"
    },
    {
                // 2B '+'
        0,      // left bearing
        6,      // right bearing
        6,      // ascent
        -1,     // descent
        8,      // width
        "\060"
        "\060"
        "\374"
        "\060"
        "\060"
    },
    {
                // 2C ','
        1,      // left bearing
        3,      // right bearing
        2,      // ascent
        2,      // descent
        5,      // width
        "\300"
        "\300"
        "\100"
        "\200"
    },
    {
                // 2D '-'
        0,      // left bearing
        4,      // right bearing
        4,      // ascent
        -3,     // descent
        6,      // width
        "\360"
    },
    {
                // 2E '.'
        1,      // left bearing
        3,      // right bearing
        2,      // ascent
        0,      // descent
        5,      // width
        "\300"
        "\300"
    },
    {
                // 2F '/'
        0,      // left bearing
        4,      // right bearing
        9,      // ascent
        0,      // descent
        5,      // width
        "\060"
        "\060"
        "\040"
        "\140"
        "\140"
        "\100"
        "\100"
        "\300"
        "\300"
    },
    {
                // 30 '0'
        0,      // left bearing
        6,      // right bearing
        9,      // ascent
        0,      // descent
        8,      // width
        "\170"
        "\314"
        "\314"
        "\314"
        "\314"
        "\314"
        "\314"
        "\314"
        "\170"
    },
    {
                // 31 '1'
        0,      // left bearing
        4,      // right bearing
        9,      // ascent
        0,      // descent
        8,      // width
        "\060"
        "\360"
        "\060"
        "\060"
        "\060"
        "\060"
        "\060"
        "\060"
        "\060"
    },
    {
                // 32 '2'
        0,      // left bearing
        6,      // right bearing
        9,      // ascent
        0,      // descent
        8,      // width
        "\170"
        "\314"
        "\014"
        "\030"
        "\060"
        "\140"
        "\300"
        "\300"
        "\374"
    },
    {
                // 33 '3'
        0,      // left bearing
        6,      // right bearing
        9,      // ascent
        0,      // descent
        8,      // width
        "\170"
        "\314"
        "\014"
        "\070"
        "\014"
        "\014"
        "\014"
        "\314"
        "\170"
    },
    {
                // 34 '4'
        0,      // left bearing
        7,      // right bearing
        9,      // ascent
        0,      // descent
        8,      // width
        "\014"
        "\034"
        "\054"
        "\054"
        "\114"
        "\214"
        "\376"
        "\014"
        "\014"
    },
    {
                // 35 '5'
        0,      // left bearing
        6,      // right bearing
        9,      // ascent
        0,      // descent
        8,      // width
        "\174"
        "\140"
        "\300"
        "\370"
        "\014"
        "\014"
        "\314"
        "\314"
        "\170"
    },
    {
                // 36 '6'
        0,      // left bearing
        6,      // right bearing
        9,      // ascent
        0,      // descent
        8,      // width
        "\170"
        "\314"
        "\300"
        "\300"
        "\370"
        "\314"
        "\314"
        "\314"
        "\170"
    },
    {
                // 37 '7'
        0,      // left bearing
        6,      // right bearing
        9,      // ascent
        0,      // descent
        8,      // width
        "\374"
        "\014"
        "\030"
        "\030"
        "\060"
        "\060"
        "\060"
        "\140"
        "\140"
    },
    {
                // 38 '8'
        0,      // left bearing
        6,      // right bearing
        9,      // ascent
        0,      // descent
        8,      // width
        "\170"
        "\314"
        "\314"
        "\170"
        "\314"
        "\314"
        "\314"
        "\314"
        "\170"
    },
    {
                // 39 '9'
        0,      // left bearing
        6,      // right bearing
        9,      // ascent
        0,      // descent
        8,      // width
        "\170"
        "\314"
        "\314"
        "\314"
        "\174"
        "\014"
        "\014"
        "\314"
        "\170"
    },
    {
                // 3A ':'
        1,      // left bearing
        3,      // right bearing
        7,      // ascent
        0,      // descent
        5,      // width
        "\300"
        "\300"
        "\000"
        "\000"
        "\000"
        "\300"
        "\300"
    },
    {
                // 3B ';'
        1,      // left bearing
        3,      // right bearing
        7,      // ascent
        2,      // descent
        5,      // width
        "\300"
        "\300"
        "\000"
        "\000"
        "\000"
        "\300"
        "\300"
        "\100"
        "\200"
    },
    {
                // 3C '<'
        1,      // left bearing
        6,      // right bearing
        6,      // ascent
        -1,     // descent
        8,      // width
        "\030"
        "\160"
        "\300"
        "\160"
        "\030"
    },
    {
                // 3D '='
        0,      // left bearing
        6,      // right bearing
        5,      // ascent
        -2,     // descent
        8,      // width
        "\374"
        "\000"
        "\374"
    },
    {
                // 3E '>'
        1,      // left bearing
        6,      // right bearing
        6,      // ascent
        -1,     // descent
        8,      // width
        "\300"
        "\160"
        "\030"
        "\160"
        "\300"
    },
    {
                // 3F '?'
        1,      // left bearing
        7,      // right bearing
        9,      // ascent
        0,      // descent
        9,      // width
        "\170"
        "\314"
        "\314"
        "\030"
        "\060"
        "\060"
        "\000"
        "\060"
        "\060"
    },
    {
                // 40 '@'
        1,      // left bearing
        11,     // right bearing
        9,      // ascent
        1,      // descent
        13,     // width
        "\037\000"
        "\140\200"
        "\100\100"
        "\215\100"
        "\222\100"
        "\242\100"
        "\246\200"
        "\233\000"
        "\100\000"
        "\076\000"
    },
    {
                // 41 'A'
        0,      // left bearing
        8,      // right bearing
        9,      // ascent
        0,      // descent
        9,      // width
        "\030"
        "\074"
        "\044"
        "\146"
        "\146"
        "\176"
        "\303"
        "\303"
        "\303"
    },
    {
                // 42 'B'
        1,      // left bearing
        8,      // right bearing
        9,      // ascent
        0,      // descent
        10,     // width
        "\374"
        "\306"
        "\306"
        "\306"
        "\374"
        "\306"
        "\306"
        "\306"
        "\374"
    },
    {
                // 43 'C'
        1,      // left bearing
        8,      // right bearing
        9,      // ascent
        0,      // descent
        9,      // width
        "\074"
        "\146"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\146"
        "\074"
    },
    {
                // 44 'D'
        1,      // left bearing
        8,      // right bearing
        9,      // ascent
        0,      // descent
        10,     // width
        "\370"
        "\314"
        "\306"
        "\306"
        "\306"
        "\306"
        "\306"
        "\314"
        "\370"
    },
    {
                // 45 'E'
        1,      // left bearing
        7,      // right bearing
        9,      // ascent
        0,      // descent
        9,      // width
        "\374"
        "\300"
        "\300"
        "\300"
        "\374"
        "\300"
        "\300"
        "\300"
        "\374"
    },
    {
                // 46 'F'
        1,      // left bearing
        7,      // right bearing
        9,      // ascent
        0,      // descent
        8,      // width
        "\374"
        "\300"
        "\300"
        "\300"
        "\370"
        "\300"
        "\300"
        "\300"
        "\300"
    },
    {
                // 47 'G'
        1,      // left bearing
        9,      // right bearing
        9,      // ascent
        0,      // descent
        11,     // width
        "\076"
        "\143"
        "\300"
        "\300"
        "\317"
        "\303"
        "\303"
        "\143"
        "\075"
    },
    {
                // 48 'H'
        1,      // left bearing
        8,      // right bearing
        9,      // ascent
        0,      // descent
        10,     // width
        "\306"
        "\306"
        "\306"
        "\306"
        "\376"
        "\306"
        "\306"
        "\306"
        "\306"
    },
    {
                // 49 'I'
        1,      // left bearing
        3,      // right bearing
        9,      // ascent
        0,      // descent
        5,      // width
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
    },
    {
                // 4A 'J'
        0,      // left bearing
        6,      // right bearing
        9,      // ascent
        0,      // descent
        8,      // width
        "\014"
        "\014"
        "\014"
        "\014"
        "\014"
        "\014"
        "\314"
        "\314"
        "\170"
    },
    {
                // 4B 'K'
        1,      // left bearing
        9,      // right bearing
        9,      // ascent
        0,      // descent
        10,     // width
        "\306"
        "\314"
        "\330"
        "\360"
        "\360"
        "\330"
        "\314"
        "\306"
        "\303"
    },
    {
                // 4C 'L'
        1,      // left bearing
        7,      // right bearing
        9,      // ascent
        0,      // descent
        8,      // width
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\374"
    },
    {
                // 4D 'M'
        1,      // left bearing
        10,     // right bearing
        9,      // ascent
        0,      // descent
        12,     // width
        "\301\200"
        "\301\200"
        "\343\200"
        "\343\200"
        "\367\200"
        "\325\200"
        "\335\200"
        "\311\200"
        "\311\200"
    },
    {
                // 4E 'N'
        1,      // left bearing
        8,      // right bearing
        9,      // ascent
        0,      // descent
        10,     // width
        "\306"
        "\346"
        "\346"
        "\326"
        "\326"
        "\316"
        "\316"
        "\306"
        "\306"
    },
    {
                // 4F 'O'
        1,      // left bearing
        9,      // right bearing
        9,      // ascent
        0,      // descent
        11,     // width
        "\074"
        "\146"
        "\303"
        "\303"
        "\303"
        "\303"
        "\303"
        "\146"
        "\074"
    },
    {
                // 50 'P'
        1,      // left bearing
        8,      // right bearing
        9,      // ascent
        0,      // descent
        9,      // width
        "\374"
        "\306"
        "\306"
        "\306"
        "\374"
        "\300"
        "\300"
        "\300"
        "\300"
    },
    {
                // 51 'Q'
        1,      // left bearing
        9,      // right bearing
        9,      // ascent
        0,      // descent
        11,     // width
        "\074"
        "\146"
        "\303"
        "\303"
        "\303"
        "\313"
        "\317"
        "\146"
        "\077"
    },
    {
                // 52 'R'
        1,      // left bearing
        8,      // right bearing
        9,      // ascent
        0,      // descent
        10,     // width
        "\374"
        "\306"
        "\306"
        "\306"
        "\374"
        "\314"
        "\306"
        "\306"
        "\306"
    },
    {
                // 53 'S'
        1,      // left bearing
        8,      // right bearing
        9,      // ascent
        0,      // descent
        10,     // width
        "\174"
        "\306"
        "\306"
        "\160"
        "\034"
        "\016"
        "\306"
        "\306"
        "\174"
    },
    {
                // 54 'T'
        0,      // left bearing
        8,      // right bearing
        9,      // ascent
        0,      // descent
        9,      // width
        "\377"
        "\030"
        "\030"
        "\030"
        "\030"
        "\030"
        "\030"
        "\030"
        "\030"
    },
    {
                // 55 'U'
        1,      // left bearing
        8,      // right bearing
        9,      // ascent
        0,      // descent
        10,     // width
        "\306"
        "\306"
        "\306"
        "\306"
        "\306"
        "\306"
        "\306"
        "\154"
        "\174"
    },
    {
                // 56 'V'
        0,      // left bearing
        8,      // right bearing
        9,      // ascent
        0,      // descent
        9,      // width
        "\303"
        "\303"
        "\146"
        "\146"
        "\146"
        "\044"
        "\074"
        "\030"
        "\030"
    },
    {
                // 57 'W'
        0,      // left bearing
        10,     // right bearing
        9,      // ascent
        0,      // descent
        11,     // width
        "\314\300"
        "\314\300"
        "\314\300"
        "\114\200"
        "\155\200"
        "\155\200"
        "\063\000"
        "\063\000"
        "\063\000"
    },
    {
                // 58 'X'
        0,      // left bearing
        8,      // right bearing
        9,      // ascent
        0,      // descent
        9,      // width
        "\303"
        "\303"
        "\146"
        "\074"
        "\030"
        "\074"
        "\146"
        "\303"
        "\303"
    },
    {
                // 59 'Y'
        0,      // left bearing
        8,      // right bearing
        9,      // ascent
        0,      // descent
        9,      // width
        "\303"
        "\303"
        "\146"
        "\146"
        "\074"
        "\030"
        "\030"
        "\030"
        "\030"
    },
    {
                // 5A 'Z'
        0,      // left bearing
        7,      // right bearing
        9,      // ascent
        0,      // descent
        8,      // width
        "\376"
        "\006"
        "\014"
        "\030"
        "\060"
        "\060"
        "\140"
        "\300"
        "\376"
    },
    {
                // 5B '['
        1,      // left bearing
        4,      // right bearing
        9,      // ascent
        3,      // descent
        5,      // width
        "\340"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\340"
    },
    {
                // 5C '\'
        0,      // left bearing
        4,      // right bearing
        9,      // ascent
        0,      // descent
        5,      // width
        "\300"
        "\300"
        "\100"
        "\140"
        "\140"
        "\040"
        "\040"
        "\060"
        "\060"
    },
    {
                // 5D ']'
        0,      // left bearing
        3,      // right bearing
        9,      // ascent
        3,      // descent
        5,      // width
        "\340"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\340"
    },
    {
                // 5E '^'
        0,      // left bearing
        7,      // right bearing
        9,      // ascent
        -5,     // descent
        8,      // width
        "\020"
        "\070"
        "\154"
        "\306"
    },
    {
                // 5F '_'
        0,      // left bearing
        7,      // right bearing
        -2,     // ascent
        3,      // descent
        8,      // width
        "\376"
    },
    {
                // 60 '`'
        0,      // left bearing
        3,      // right bearing
        10,     // ascent
        -8,     // descent
        5,      // width
        "\300"
        "\140"
    },
    {
                // 61 'a'
        0,      // left bearing
        7,      // right bearing
        7,      // ascent
        0,      // descent
        8,      // width
        "\170"
        "\314"
        "\014"
        "\174"
        "\314"
        "\314"
        "\166"
    },
    {
                // 62 'b'
        0,      // left bearing
        6,      // right bearing
        9,      // ascent
        0,      // descent
        8,      // width
        "\300"
        "\300"
        "\330"
        "\354"
        "\314"
        "\314"
        "\314"
        "\354"
        "\330"
    },
    {
                // 63 'c'
        0,      // left bearing
        6,      // right bearing
        7,      // ascent
        0,      // descent
        8,      // width
        "\170"
        "\314"
        "\300"
        "\300"
        "\300"
        "\314"
        "\170"
    },
    {
                // 64 'd'
        0,      // left bearing
        6,      // right bearing
        9,      // ascent
        0,      // descent
        8,      // width
        "\014"
        "\014"
        "\154"
        "\334"
        "\314"
        "\314"
        "\314"
        "\334"
        "\154"
    },
    {
                // 65 'e'
        0,      // left bearing
        6,      // right bearing
        7,      // ascent
        0,      // descent
        8,      // width
        "\170"
        "\314"
        "\314"
        "\374"
        "\300"
        "\314"
        "\170"
    },
    {
                // 66 'f'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        6,      // width
        "\070"
        "\140"
        "\360"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
    },
    {
                // 67 'g'
        0,      // left bearing
        6,      // right bearing
        7,      // ascent
        3,      // descent
        8,      // width
        "\154"
        "\334"
        "\314"
        "\314"
        "\314"
        "\334"
        "\154"
        "\014"
        "\314"
        "\170"
    },
    {
                // 68 'h'
        0,      // left bearing
        6,      // right bearing
        9,      // ascent
        0,      // descent
        8,      // width
        "\300"
        "\300"
        "\330"
        "\354"
        "\314"
        "\314"
        "\314"
        "\314"
        "\314"
    },
    {
                // 69 'i'
        0,      // left bearing
        2,      // right bearing
        9,      // ascent
        0,      // descent
        4,      // width
        "\300"
        "\000"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
    },
    {
                // 6A 'j'
        -1,     // left bearing
        2,      // right bearing
        9,      // ascent
        3,      // descent
        4,      // width
        "\140"
        "\000"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\300"
    },
    {
                // 6B 'k'
        0,      // left bearing
        7,      // right bearing
        9,      // ascent
        0,      // descent
        8,      // width
        "\300"
        "\300"
        "\314"
        "\330"
        "\360"
        "\360"
        "\330"
        "\314"
        "\306"
    },
    {
                // 6C 'l'
        0,      // left bearing
        2,      // right bearing
        9,      // ascent
        0,      // descent
        4,      // width
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
    },
    {
                // 6D 'm'
        0,      // left bearing
        10,     // right bearing
        7,      // ascent
        0,      // descent
        12,     // width
        "\273\200"
        "\314\300"
        "\314\300"
        "\314\300"
        "\314\300"
        "\314\300"
        "\314\300"
    },
    {
                // 6E 'n'
        0,      // left bearing
        6,      // right bearing
        7,      // ascent
        0,      // descent
        8,      // width
        "\330"
        "\354"
        "\314"
        "\314"
        "\314"
        "\314"
        "\314"
    },
    {
                // 6F 'o'
        0,      // left bearing
        6,      // right bearing
        7,      // ascent
        0,      // descent
        8,      // width
        "\170"
        "\314"
        "\314"
        "\314"
        "\314"
        "\314"
        "\170"
    },
    {
                // 70 'p'
        0,      // left bearing
        6,      // right bearing
        7,      // ascent
        3,      // descent
        8,      // width
        "\330"
        "\354"
        "\314"
        "\314"
        "\314"
        "\354"
        "\330"
        "\300"
        "\300"
        "\300"
    },
    {
                // 71 'q'
        0,      // left bearing
        6,      // right bearing
        7,      // ascent
        3,      // descent
        8,      // width
        "\164"
        "\334"
        "\314"
        "\314"
        "\314"
        "\334"
        "\154"
        "\014"
        "\014"
        "\014"
    },
    {
                // 72 'r'
        0,      // left bearing
        5,      // right bearing
        7,      // ascent
        0,      // descent
        6,      // width
        "\330"
        "\370"
        "\340"
        "\300"
        "\300"
        "\300"
        "\300"
    },
    {
                // 73 's'
        0,      // left bearing
        6,      // right bearing
        7,      // ascent
        0,      // descent
        8,      // width
        "\170"
        "\314"
        "\340"
        "\070"
        "\034"
        "\314"
        "\170"
    },
    {
                // 74 't'
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        0,      // descent
        6,      // width
        "\140"
        "\140"
        "\360"
        "\140"
        "\140"
        "\140"
        "\140"
        "\150"
        "\060"
    },
    {
                // 75 'u'
        0,      // left bearing
        6,      // right bearing
        7,      // ascent
        0,      // descent
        8,      // width
        "\314"
        "\314"
        "\314"
        "\314"
        "\314"
        "\334"
        "\154"
    },
    {
                // 76 'v'
        0,      // left bearing
        7,      // right bearing
        7,      // ascent
        0,      // descent
        9,      // width
        "\306"
        "\306"
        "\154"
        "\154"
        "\070"
        "\070"
        "\020"
    },
    {
                // 77 'w'
        0,      // left bearing
        10,     // right bearing
        7,      // ascent
        0,      // descent
        12,     // width
        "\314\300"
        "\314\300"
        "\155\200"
        "\155\200"
        "\155\200"
        "\063\000"
        "\063\000"
    },
    {
                // 78 'x'
        0,      // left bearing
        6,      // right bearing
        7,      // ascent
        0,      // descent
        8,      // width
        "\314"
        "\314"
        "\170"
        "\060"
        "\170"
        "\314"
        "\314"
    },
    {
                // 79 'y'
        0,      // left bearing
        7,      // right bearing
        7,      // ascent
        3,      // descent
        9,      // width
        "\306"
        "\306"
        "\154"
        "\154"
        "\070"
        "\070"
        "\030"
        "\020"
        "\060"
        "\140"
    },
    {
                // 7A 'z'
        0,      // left bearing
        5,      // right bearing
        7,      // ascent
        0,      // descent
        7,      // width
        "\370"
        "\030"
        "\060"
        "\040"
        "\140"
        "\300"
        "\370"
    },
    {
                // 7B '{'
        0,      // left bearing
        4,      // right bearing
        9,      // ascent
        3,      // descent
        6,      // width
        "\060"
        "\140"
        "\140"
        "\140"
        "\140"
        "\300"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\060"
    },
    {
                // 7C '|'
        1,      // left bearing
        3,      // right bearing
        9,      // ascent
        3,      // descent
        5,      // width
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
    },
    {
                // 7D '}'
        0,      // left bearing
        4,      // right bearing
        9,      // ascent
        3,      // descent
        6,      // width
        "\300"
        "\140"
        "\140"
        "\140"
        "\140"
        "\060"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\300"
    },
    {
                // 7E '~'
        0,      // left bearing
        7,      // right bearing
        5,      // ascent
        -3,     // descent
        8,      // width
        "\166"
        "\334"
    },
    {
                // 7F
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 80
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 81
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 82
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 83
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 84
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 85
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 86
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 87
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 88
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 89
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 8A
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 8B
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 8C
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 8D
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 8E
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 8F
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 90
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 91
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 92
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 93
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 94
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 95
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 96
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 97
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 98
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 99
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 9A
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 9B
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 9C
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 9D
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 9E
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // 9F
        0,      // left bearing
        0,      // right bearing
        0,      // ascent
        0,      // descent
        1,      // width
    },
    {
                // A0
        0,      // left bearing
        1,      // right bearing
        1,      // ascent
        0,      // descent
        5,      // width
        "\000"
    },
    {
                // A1
        1,      // left bearing
        3,      // right bearing
        7,      // ascent
        3,      // descent
        5,      // width
        "\300"
        "\300"
        "\000"
        "\100"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
    },
    {
                // A2
        0,      // left bearing
        6,      // right bearing
        8,      // ascent
        1,      // descent
        8,      // width
        "\020"
        "\170"
        "\334"
        "\220"
        "\240"
        "\240"
        "\354"
        "\170"
        "\100"
    },
    {
                // A3
        0,      // left bearing
        6,      // right bearing
        9,      // ascent
        0,      // descent
        8,      // width
        "\070"
        "\154"
        "\140"
        "\140"
        "\370"
        "\140"
        "\140"
        "\354"
        "\330"
    },
    {
                // A4
        0,      // left bearing
        6,      // right bearing
        7,      // ascent
        -1,     // descent
        8,      // width
        "\314"
        "\170"
        "\110"
        "\110"
        "\170"
        "\314"
    },
    {
                // A5
        0,      // left bearing
        6,      // right bearing
        9,      // ascent
        0,      // descent
        8,      // width
        "\314"
        "\314"
        "\110"
        "\374"
        "\060"
        "\374"
        "\060"
        "\060"
        "\060"
    },
    {
                // A6
        1,      // left bearing
        3,      // right bearing
        9,      // ascent
        2,      // descent
        5,      // width
        "\300"
        "\300"
        "\300"
        "\300"
        "\000"
        "\000"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
    },
    {
                // A7
        0,      // left bearing
        6,      // right bearing
        9,      // ascent
        3,      // descent
        8,      // width
        "\170"
        "\314"
        "\340"
        "\160"
        "\330"
        "\314"
        "\314"
        "\154"
        "\070"
        "\034"
        "\314"
        "\170"
    },
    {
                // A8
        0,      // left bearing
        5,      // right bearing
        9,      // ascent
        -8,     // descent
        6,      // width
        "\330"
    },
    {
                // A9
        1,      // left bearing
        10,     // right bearing
        9,      // ascent
        0,      // descent
        12,     // width
        "\076\000"
        "\101\000"
        "\234\200"
        "\242\200"
        "\240\200"
        "\242\200"
        "\234\200"
        "\101\000"
        "\076\000"
    },
    {
                // AA
        1,      // left bearing
        5,      // right bearing
        9,      // ascent
        -3,     // descent
        7,      // width
        "\340"
        "\060"
        "\360"
        "\260"
        "\000"
        "\360"
    },
    {
                // AB
        1,      // left bearing
        7,      // right bearing
        6,      // ascent
        -1,     // descent
        9,      // width
        "\044"
        "\154"
        "\330"
        "\154"
        "\044"
    },
    {
                // AC
        1,      // left bearing
        7,      // right bearing
        6,      // ascent
        -2,     // descent
        9,      // width
        "\374"
        "\004"
        "\004"
        "\004"
    },
    {
                // AD
        0,      // left bearing
        4,      // right bearing
        4,      // ascent
        -3,     // descent
        6,      // width
        "\360"
    },
    {
                // AE
        1,      // left bearing
        10,     // right bearing
        9,      // ascent
        0,      // descent
        12,     // width
        "\076\000"
        "\101\000"
        "\234\200"
        "\224\200"
        "\230\200"
        "\224\200"
        "\224\200"
        "\101\000"
        "\076\000"
    },
    {
                // AF
        0,      // left bearing
        4,      // right bearing
        9,      // ascent
        -8,     // descent
        5,      // width
        "\360"
    },
    {
                // B0
        0,      // left bearing
        4,      // right bearing
        8,      // ascent
        -4,     // descent
        6,      // width
        "\140"
        "\220"
        "\220"
        "\140"
    },
    {
                // B1
        0,      // left bearing
        6,      // right bearing
        7,      // ascent
        0,      // descent
        8,      // width
        "\060"
        "\060"
        "\374"
        "\060"
        "\060"
        "\000"
        "\374"
    },
    {
                // B2
        0,      // left bearing
        4,      // right bearing
        9,      // ascent
        -4,     // descent
        5,      // width
        "\140"
        "\260"
        "\140"
        "\300"
        "\360"
    },
    {
                // B3
        0,      // left bearing
        4,      // right bearing
        9,      // ascent
        -4,     // descent
        5,      // width
        "\140"
        "\260"
        "\140"
        "\060"
        "\340"
    },
    {
                // B4
        0,      // left bearing
        3,      // right bearing
        10,     // ascent
        -8,     // descent
        5,      // width
        "\140"
        "\300"
    },
    {
                // B5
        0,      // left bearing
        6,      // right bearing
        7,      // ascent
        3,      // descent
        8,      // width
        "\314"
        "\314"
        "\314"
        "\314"
        "\314"
        "\334"
        "\354"
        "\300"
        "\300"
        "\300"
    },
    {
                // B6
        0,      // left bearing
        7,      // right bearing
        9,      // ascent
        3,      // descent
        8,      // width
        "\076"
        "\164"
        "\364"
        "\364"
        "\364"
        "\164"
        "\064"
        "\024"
        "\024"
        "\024"
        "\024"
        "\024"
    },
    {
                // B7
        1,      // left bearing
        3,      // right bearing
        5,      // ascent
        -3,     // descent
        5,      // width
        "\300"
        "\300"
    },
    {
                // B8
        0,      // left bearing
        4,      // right bearing
        1,      // ascent
        3,      // descent
        5,      // width
        "\140"
        "\060"
        "\060"
        "\340"
    },
    {
                // B9
        0,      // left bearing
        3,      // right bearing
        9,      // ascent
        -4,     // descent
        5,      // width
        "\140"
        "\340"
        "\140"
        "\140"
        "\140"
    },
    {
                // BA
        1,      // left bearing
        5,      // right bearing
        9,      // ascent
        -3,     // descent
        7,      // width
        "\140"
        "\320"
        "\320"
        "\140"
        "\000"
        "\360"
    },
    {
                // BB
        1,      // left bearing
        7,      // right bearing
        6,      // ascent
        -1,     // descent
        9,      // width
        "\220"
        "\330"
        "\154"
        "\330"
        "\220"
    },
    {
                // BC
        0,      // left bearing
        10,     // right bearing
        9,      // ascent
        0,      // descent
        11,     // width
        "\143\000"
        "\346\000"
        "\146\000"
        "\154\000"
        "\155\200"
        "\013\200"
        "\032\200"
        "\067\300"
        "\061\200"
    },
    {
                // BD
        0,      // left bearing
        10,     // right bearing
        9,      // ascent
        0,      // descent
        11,     // width
        "\143\000"
        "\346\000"
        "\146\000"
        "\154\000"
        "\155\200"
        "\012\300"
        "\031\200"
        "\063\000"
        "\063\300"
    },
    {
                // BE
        0,      // left bearing
        10,     // right bearing
        9,      // ascent
        0,      // descent
        11,     // width
        "\143\000"
        "\263\000"
        "\146\000"
        "\066\000"
        "\355\200"
        "\013\200"
        "\032\200"
        "\067\300"
        "\061\200"
    },
    {
                // BF
        1,      // left bearing
        7,      // right bearing
        7,      // ascent
        3,      // descent
        9,      // width
        "\060"
        "\060"
        "\000"
        "\060"
        "\060"
        "\060"
        "\140"
        "\314"
        "\314"
        "\170"
    },
    {
                // C0
        0,      // left bearing
        8,      // right bearing
        12,     // ascent
        0,      // descent
        9,      // width
        "\060"
        "\030"
        "\000"
        "\030"
        "\030"
        "\074"
        "\044"
        "\146"
        "\176"
        "\303"
        "\303"
        "\303"
    },
    {
                // C1
        0,      // left bearing
        8,      // right bearing
        12,     // ascent
        0,      // descent
        9,      // width
        "\014"
        "\030"
        "\000"
        "\030"
        "\030"
        "\074"
        "\044"
        "\146"
        "\176"
        "\303"
        "\303"
        "\303"
    },
    {
                // C2
        0,      // left bearing
        8,      // right bearing
        12,     // ascent
        0,      // descent
        9,      // width
        "\034"
        "\066"
        "\000"
        "\030"
        "\030"
        "\074"
        "\044"
        "\146"
        "\176"
        "\303"
        "\303"
        "\303"
    },
    {
                // C3
        0,      // left bearing
        8,      // right bearing
        12,     // ascent
        0,      // descent
        9,      // width
        "\032"
        "\054"
        "\000"
        "\030"
        "\030"
        "\074"
        "\044"
        "\146"
        "\176"
        "\303"
        "\303"
        "\303"
    },
    {
                // C4
        0,      // left bearing
        8,      // right bearing
        11,     // ascent
        0,      // descent
        9,      // width
        "\066"
        "\000"
        "\030"
        "\030"
        "\074"
        "\044"
        "\146"
        "\176"
        "\303"
        "\303"
        "\303"
    },
    {
                // C5
        0,      // left bearing
        8,      // right bearing
        12,     // ascent
        0,      // descent
        9,      // width
        "\030"
        "\044"
        "\030"
        "\030"
        "\030"
        "\074"
        "\044"
        "\146"
        "\176"
        "\303"
        "\303"
        "\303"
    },
    {
                // C6
        1,      // left bearing
        12,     // right bearing
        9,      // ascent
        0,      // descent
        14,     // width
        "\037\340"
        "\066\000"
        "\046\000"
        "\146\000"
        "\147\340"
        "\176\000"
        "\306\000"
        "\306\000"
        "\307\340"
    },
    {
                // C7
        1,      // left bearing
        8,      // right bearing
        9,      // ascent
        3,      // descent
        9,      // width
        "\074"
        "\146"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\146"
        "\074"
        "\030"
        "\030"
        "\160"
    },
    {
                // C8
        1,      // left bearing
        7,      // right bearing
        12,     // ascent
        0,      // descent
        9,      // width
        "\140"
        "\060"
        "\000"
        "\374"
        "\300"
        "\300"
        "\300"
        "\374"
        "\300"
        "\300"
        "\300"
        "\374"
    },
    {
                // C9
        1,      // left bearing
        7,      // right bearing
        12,     // ascent
        0,      // descent
        9,      // width
        "\030"
        "\060"
        "\000"
        "\374"
        "\300"
        "\300"
        "\300"
        "\374"
        "\300"
        "\300"
        "\300"
        "\374"
    },
    {
                // CA
        1,      // left bearing
        7,      // right bearing
        12,     // ascent
        0,      // descent
        9,      // width
        "\070"
        "\154"
        "\000"
        "\374"
        "\300"
        "\300"
        "\300"
        "\374"
        "\300"
        "\300"
        "\300"
        "\374"
    },
    {
                // CB
        1,      // left bearing
        7,      // right bearing
        11,     // ascent
        0,      // descent
        9,      // width
        "\154"
        "\000"
        "\374"
        "\300"
        "\300"
        "\300"
        "\374"
        "\300"
        "\300"
        "\300"
        "\374"
    },
    {
                // CC
        0,      // left bearing
        3,      // right bearing
        12,     // ascent
        0,      // descent
        5,      // width
        "\300"
        "\140"
        "\000"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
    },
    {
                // CD
        1,      // left bearing
        4,      // right bearing
        12,     // ascent
        0,      // descent
        5,      // width
        "\140"
        "\300"
        "\000"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
    },
    {
                // CE
        0,      // left bearing
        5,      // right bearing
        12,     // ascent
        0,      // descent
        5,      // width
        "\160"
        "\330"
        "\000"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
    },
    {
                // CF
        0,      // left bearing
        5,      // right bearing
        11,     // ascent
        0,      // descent
        5,      // width
        "\330"
        "\000"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
    },
    {
                // D0
        0,      // left bearing
        8,      // right bearing
        9,      // ascent
        0,      // descent
        10,     // width
        "\174"
        "\146"
        "\143"
        "\143"
        "\363"
        "\143"
        "\143"
        "\146"
        "\174"
    },
    {
                // D1
        1,      // left bearing
        8,      // right bearing
        12,     // ascent
        0,      // descent
        10,     // width
        "\064"
        "\130"
        "\000"
        "\306"
        "\306"
        "\346"
        "\346"
        "\366"
        "\316"
        "\316"
        "\306"
        "\306"
    },
    {
                // D2
        1,      // left bearing
        9,      // right bearing
        12,     // ascent
        0,      // descent
        11,     // width
        "\060"
        "\030"
        "\000"
        "\074"
        "\146"
        "\303"
        "\303"
        "\303"
        "\303"
        "\303"
        "\146"
        "\074"
    },
    {
                // D3
        1,      // left bearing
        9,      // right bearing
        12,     // ascent
        0,      // descent
        11,     // width
        "\014"
        "\030"
        "\000"
        "\074"
        "\146"
        "\303"
        "\303"
        "\303"
        "\303"
        "\303"
        "\146"
        "\074"
    },
    {
                // D4
        1,      // left bearing
        9,      // right bearing
        12,     // ascent
        0,      // descent
        11,     // width
        "\034"
        "\066"
        "\000"
        "\074"
        "\146"
        "\303"
        "\303"
        "\303"
        "\303"
        "\303"
        "\146"
        "\074"
    },
    {
                // D5
        1,      // left bearing
        9,      // right bearing
        12,     // ascent
        0,      // descent
        11,     // width
        "\032"
        "\054"
        "\000"
        "\074"
        "\146"
        "\303"
        "\303"
        "\303"
        "\303"
        "\303"
        "\146"
        "\074"
    },
    {
                // D6
        1,      // left bearing
        9,      // right bearing
        11,     // ascent
        0,      // descent
        11,     // width
        "\146"
        "\000"
        "\074"
        "\146"
        "\303"
        "\303"
        "\303"
        "\303"
        "\303"
        "\146"
        "\074"
    },
    {
                // D7
        0,      // left bearing
        6,      // right bearing
        6,      // ascent
        -1,     // descent
        8,      // width
        "\314"
        "\170"
        "\060"
        "\170"
        "\314"
    },
    {
                // D8
        1,      // left bearing
        9,      // right bearing
        9,      // ascent
        1,      // descent
        11,     // width
        "\075"
        "\146"
        "\317"
        "\313"
        "\333"
        "\323"
        "\363"
        "\146"
        "\174"
        "\200"
    },
    {
                // D9
        1,      // left bearing
        8,      // right bearing
        12,     // ascent
        0,      // descent
        10,     // width
        "\060"
        "\030"
        "\000"
        "\306"
        "\306"
        "\306"
        "\306"
        "\306"
        "\306"
        "\306"
        "\154"
        "\174"
    },
    {
                // DA
        1,      // left bearing
        8,      // right bearing
        12,     // ascent
        0,      // descent
        10,     // width
        "\014"
        "\030"
        "\000"
        "\306"
        "\306"
        "\306"
        "\306"
        "\306"
        "\306"
        "\306"
        "\154"
        "\174"
    },
    {
                // DB
        1,      // left bearing
        8,      // right bearing
        12,     // ascent
        0,      // descent
        10,     // width
        "\070"
        "\154"
        "\000"
        "\306"
        "\306"
        "\306"
        "\306"
        "\306"
        "\306"
        "\306"
        "\154"
        "\174"
    },
    {
                // DC
        1,      // left bearing
        8,      // right bearing
        11,     // ascent
        0,      // descent
        10,     // width
        "\154"
        "\000"
        "\306"
        "\306"
        "\306"
        "\306"
        "\306"
        "\306"
        "\306"
        "\154"
        "\174"
    },
    {
                // DD
        0,      // left bearing
        8,      // right bearing
        12,     // ascent
        0,      // descent
        9,      // width
        "\014"
        "\030"
        "\000"
        "\303"
        "\303"
        "\146"
        "\146"
        "\044"
        "\074"
        "\030"
        "\030"
        "\030"
    },
    {
                // DE
        1,      // left bearing
        8,      // right bearing
        9,      // ascent
        0,      // descent
        9,      // width
        "\300"
        "\300"
        "\374"
        "\306"
        "\306"
        "\306"
        "\374"
        "\300"
        "\300"
    },
    {
                // DF
        1,      // left bearing
        7,      // right bearing
        9,      // ascent
        0,      // descent
        9,      // width
        "\170"
        "\314"
        "\314"
        "\314"
        "\330"
        "\314"
        "\314"
        "\314"
        "\330"
    },
    {
                // E0
        0,      // left bearing
        7,      // right bearing
        10,     // ascent
        0,      // descent
        8,      // width
        "\060"
        "\030"
        "\000"
        "\170"
        "\314"
        "\014"
        "\174"
        "\314"
        "\314"
        "\166"
    },
    {
                // E1
        0,      // left bearing
        7,      // right bearing
        10,     // ascent
        0,      // descent
        8,      // width
        "\030"
        "\060"
        "\000"
        "\170"
        "\314"
        "\014"
        "\174"
        "\314"
        "\314"
        "\166"
    },
    {
                // E2
        0,      // left bearing
        7,      // right bearing
        10,     // ascent
        0,      // descent
        8,      // width
        "\070"
        "\154"
        "\000"
        "\170"
        "\314"
        "\014"
        "\174"
        "\314"
        "\314"
        "\166"
    },
    {
                // E3
        0,      // left bearing
        7,      // right bearing
        10,     // ascent
        0,      // descent
        8,      // width
        "\064"
        "\130"
        "\000"
        "\170"
        "\314"
        "\014"
        "\174"
        "\314"
        "\314"
        "\166"
    },
    {
                // E4
        0,      // left bearing
        7,      // right bearing
        9,      // ascent
        0,      // descent
        8,      // width
        "\154"
        "\000"
        "\170"
        "\314"
        "\014"
        "\174"
        "\314"
        "\314"
        "\166"
    },
    {
                // E5
        0,      // left bearing
        7,      // right bearing
        11,     // ascent
        0,      // descent
        8,      // width
        "\060"
        "\110"
        "\060"
        "\000"
        "\170"
        "\314"
        "\014"
        "\174"
        "\314"
        "\314"
        "\166"
    },
    {
                // E6
        0,      // left bearing
        10,     // right bearing
        7,      // ascent
        0,      // descent
        12,     // width
        "\167\200"
        "\314\300"
        "\014\300"
        "\177\300"
        "\314\000"
        "\314\300"
        "\167\200"
    },
    {
                // E7
        0,      // left bearing
        6,      // right bearing
        7,      // ascent
        3,      // descent
        8,      // width
        "\170"
        "\314"
        "\300"
        "\300"
        "\300"
        "\314"
        "\170"
        "\020"
        "\030"
        "\160"
    },
    {
                // E8
        0,      // left bearing
        6,      // right bearing
        10,     // ascent
        0,      // descent
        8,      // width
        "\140"
        "\060"
        "\000"
        "\170"
        "\314"
        "\314"
        "\374"
        "\300"
        "\314"
        "\170"
    },
    {
                // E9
        0,      // left bearing
        6,      // right bearing
        10,     // ascent
        0,      // descent
        8,      // width
        "\030"
        "\060"
        "\000"
        "\170"
        "\314"
        "\314"
        "\374"
        "\300"
        "\314"
        "\170"
    },
    {
                // EA
        0,      // left bearing
        6,      // right bearing
        10,     // ascent
        0,      // descent
        8,      // width
        "\070"
        "\154"
        "\000"
        "\170"
        "\314"
        "\314"
        "\374"
        "\300"
        "\314"
        "\170"
    },
    {
                // EB
        0,      // left bearing
        6,      // right bearing
        9,      // ascent
        0,      // descent
        8,      // width
        "\154"
        "\000"
        "\170"
        "\314"
        "\314"
        "\374"
        "\300"
        "\314"
        "\170"
    },
    {
                // EC
        -1,     // left bearing
        2,      // right bearing
        10,     // ascent
        0,      // descent
        4,      // width
        "\300"
        "\140"
        "\000"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
    },
    {
                // ED
        0,      // left bearing
        3,      // right bearing
        10,     // ascent
        0,      // descent
        4,      // width
        "\140"
        "\300"
        "\000"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
        "\300"
    },
    {
                // EE
        -1,     // left bearing
        4,      // right bearing
        10,     // ascent
        0,      // descent
        4,      // width
        "\160"
        "\330"
        "\000"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
    },
    {
                // EF
        -1,     // left bearing
        4,      // right bearing
        9,      // ascent
        0,      // descent
        4,      // width
        "\330"
        "\000"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
        "\140"
    },
    {
                // F0
        0,      // left bearing
        6,      // right bearing
        10,     // ascent
        0,      // descent
        8,      // width
        "\330"
        "\160"
        "\220"
        "\030"
        "\174"
        "\314"
        "\314"
        "\314"
        "\314"
        "\170"
    },
    {
                // F1
        0,      // left bearing
        6,      // right bearing
        10,     // ascent
        0,      // descent
        8,      // width
        "\064"
        "\130"
        "\000"
        "\330"
        "\354"
        "\314"
        "\314"
        "\314"
        "\314"
        "\314"
    },
    {
                // F2
        0,      // left bearing
        6,      // right bearing
        10,     // ascent
        0,      // descent
        8,      // width
        "\140"
        "\060"
        "\000"
        "\170"
        "\314"
        "\314"
        "\314"
        "\314"
        "\314"
        "\170"
    },
    {
                // F3
        0,      // left bearing
        6,      // right bearing
        10,     // ascent
        0,      // descent
        8,      // width
        "\030"
        "\060"
        "\000"
        "\170"
        "\314"
        "\314"
        "\314"
        "\314"
        "\314"
        "\170"
    },
    {
                // F4
        0,      // left bearing
        6,      // right bearing
        10,     // ascent
        0,      // descent
        8,      // width
        "\070"
        "\154"
        "\000"
        "\170"
        "\314"
        "\314"
        "\314"
        "\314"
        "\314"
        "\170"
    },
    {
                // F5
        0,      // left bearing
        6,      // right bearing
        10,     // ascent
        0,      // descent
        8,      // width
        "\064"
        "\130"
        "\000"
        "\170"
        "\314"
        "\314"
        "\314"
        "\314"
        "\314"
        "\170"
    },
    {
                // F6
        0,      // left bearing
        6,      // right bearing
        9,      // ascent
        0,      // descent
        8,      // width
        "\154"
        "\000"
        "\170"
        "\314"
        "\314"
        "\314"
        "\314"
        "\314"
        "\170"
    },
    {
                // F7
        0,      // left bearing
        6,      // right bearing
        6,      // ascent
        -1,     // descent
        8,      // width
        "\060"
        "\000"
        "\374"
        "\000"
        "\060"
    },
    {
                // F8
        -1,     // left bearing
        7,      // right bearing
        7,      // ascent
        0,      // descent
        8,      // width
        "\075"
        "\146"
        "\156"
        "\166"
        "\146"
        "\146"
        "\274"
    },
    {
                // F9
        0,      // left bearing
        6,      // right bearing
        10,     // ascent
        0,      // descent
        8,      // width
        "\140"
        "\060"
        "\000"
        "\314"
        "\314"
        "\314"
        "\314"
        "\314"
        "\334"
        "\154"
    },
    {
                // FA
        0,      // left bearing
        6,      // right bearing
        10,     // ascent
        0,      // descent
        8,      // width
        "\030"
        "\060"
        "\000"
        "\314"
        "\314"
        "\314"
        "\314"
        "\314"
        "\334"
        "\154"
    },
    {
                // FB
        0,      // left bearing
        6,      // right bearing
        10,     // ascent
        0,      // descent
        8,      // width
        "\070"
        "\154"
        "\000"
        "\314"
        "\314"
        "\314"
        "\314"
        "\314"
        "\334"
        "\154"
    },
    {
                // FC
        0,      // left bearing
        6,      // right bearing
        9,      // ascent
        0,      // descent
        8,      // width
        "\154"
        "\000"
        "\314"
        "\314"
        "\314"
        "\314"
        "\314"
        "\334"
        "\154"
    },
    {
                // FD
        0,      // left bearing
        7,      // right bearing
        10,     // ascent
        3,      // descent
        9,      // width
        "\014"
        "\030"
        "\000"
        "\306"
        "\306"
        "\154"
        "\154"
        "\070"
        "\070"
        "\030"
        "\020"
        "\060"
        "\140"
    },
    {
                // FE
        0,      // left bearing
        6,      // right bearing
        9,      // ascent
        3,      // descent
        8,      // width
        "\300"
        "\300"
        "\330"
        "\354"
        "\314"
        "\314"
        "\314"
        "\354"
        "\330"
        "\300"
        "\300"
        "\300"
    },
    {
                // FF
        0,      // left bearing
        7,      // right bearing
        9,      // ascent
        3,      // descent
        9,      // width
        "\154"
        "\000"
        "\306"
        "\306"
        "\154"
        "\154"
        "\070"
        "\070"
        "\030"
        "\020"
        "\060"
        "\140"
    },
};

font_internal_variable::~font_internal_variable()
{
    if (glyph_ptr)
    {
        for (int j = 0; j < 256; ++j)
            delete glyph_ptr[j];
        delete [] glyph_ptr;
    }
}

font_internal_variable::font_internal_variable() :
    glyph_ptr(0)
{
}

glyph *
font_internal_variable::get_glyph(unsigned n)
{
    if (n > 256)
        n = '?';
    if (!glyph_ptr)
    {
        glyph_ptr = new glyph * [256];
        for (unsigned j = 0; j < 256; ++j)
            glyph_ptr[j] = 0;
    }
    if (!glyph_ptr[n])
        glyph_ptr[n] = new glyph_internal(table[n]);
    return glyph_ptr[n];
}

int
font_internal_variable::get_ascent()
{
    return 11;
}

int
font_internal_variable::get_descent()
{
    return 3;
}

const char *
font_internal_variable::get_name()
    const
{
    return "variable";
}
