//
//      bigtext - print big text using X11 fonts
//      Copyright (C) 2004, 2007, 2010 Peter Miller
//
//      This program is free software; you can redistribute it and/or modify
//      it under the terms of the GNU General Public License as published by
//      the Free Software Foundation; either version 3 of the License, or
//      (at your option) any later version.
//
//      This program is distributed in the hope that it will be useful,
//      but WITHOUT ANY WARRANTY; without even the implied warranty of
//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//      GNU General Public License for more details.
//
//      You should have received a copy of the GNU General Public License
//      along with this program. If not, see
//      <http://www.gnu.org/licenses/>.
//

#include <bigtext/font/xfs.h>
#include <bigtext/font_server/xfs.h>
#include <bigtext/glyph/xfs.h>


font_xfs::~font_xfs()
{
    if (id != 0)
    {
        server->close_font(id);
        id = 0;
    }
    for (unsigned j = 0; j < 256; ++j)
    {
        if (glyphs[j])
        {
            delete glyphs[j];
            glyphs[j] = 0;
        }
    }
}


font_xfs::font_xfs(font_server_xfs *arg1, const char *arg2) :
    server(arg1),
    name(arg2),
    id(0),
    min_char(0),
    max_char(0)
{
    for (unsigned j = 0; j < 256; ++j)
        glyphs[j] = 0;
}


const char *
font_xfs::get_name()
    const
{
    return name;
}


static inline unsigned
FSChar2b_to_unsigned(FSChar2b &x)
{
    return ((x.high << 8) | x.low);
}


Font
font_xfs::get_id()
{
    if (id == 0)
    {
        id = server->open_bitmap_font(name);
        FSPropInfo props;
        FSPropOffset *offsets;
        unsigned char *prop_data;
        server->query_x_info(id, &info_header, &props, &offsets, &prop_data);
        FSFree((char *)offsets);
        FSFree((char *)prop_data);

        min_char = FSChar2b_to_unsigned(info_header.char_range.min_char);
        max_char = FSChar2b_to_unsigned(info_header.char_range.max_char);
        if (max_char > 255)
            max_char = 255;
    }
    return id;
}


glyph *
font_xfs::get_glyph(unsigned c)
{
    get_id();

    if (c < min_char || c > max_char)
        c = ' ';

    if (!glyphs[c])
        glyphs[c] = new glyph_xfs(c, this);
    return glyphs[c];
}


void
font_xfs::query_x_extents_8(unsigned char c, FSXCharInfo *extent)
{
    FSXCharInfo *extents = 0;
    server->query_x_extents_8(get_id(), &c, 1, &extents);
    *extent = extents[0];
    FSFree((char *)extents);
}


void
font_xfs::query_x_bitmaps_8(unsigned char c, unsigned char **bitmap)
{
    FSOffset *offsets = 0;
    unsigned char *data = 0;
    server->query_x_bitmaps_8(id, &c, 1, &offsets, &data);
    *bitmap = data;
    FSFree((char *)offsets);
}


int
font_xfs::get_ascent()
{
    get_id();
    return info_header.font_ascent;
}


int
font_xfs::get_descent()
{
    get_id();
    return info_header.font_descent;
}
