//
// bigtext - print big text using X11 fonts
// Copyright (C) 2004, 2007, 2009, 2010 Peter Miller
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
//

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <X11/fonts/FSlib.h>

#include <bigtext/font_list.h>


font_list::~font_list()
{
    if (count)
        delete [] list[0];
    delete [] list;
    list = 0;
    count = 0;
}


font_list::font_list() :
    list(0),
    count(0)
{
}


static char **
copy_the_list(const char **list, int count)
{
    if (count <= 0)
        return 0;
    char **result = new char * [count];

    size_t nbytes = 0;
    for (int j = 0; j < count; ++j)
    {
        const char *s = list[j];
        size_t len = strlen(s) + 1;
        nbytes += len;
    }
    char *cp = new char[nbytes];
    for (int k = 0; k < count; ++k)
    {
        const char *s = list[k];
        result[k] = cp;
        size_t len = strlen(s) + 1;
        memcpy(cp, s, len);
        cp += len;
    }
    return result;
}


font_list::font_list(const char **arg1, int arg2) :
    list(copy_the_list(arg1, arg2)),
    count(arg2)
{
    // This constructor is called with the results of FSListFonts, and
    // assumes responsibility for calling FSFreeFontNames when its done
    // with.
}


font_list::font_list(const font_list &arg) :
    list(copy_the_list((const char **)arg.list, arg.count)),
    count(arg.count)
{
}


font_list &
font_list::operator=(const font_list &arg)
{
    if (this != &arg)
    {
        FSFreeFontNames(list);
        list = copy_the_list((const char **)arg.list, arg.count);
        count = arg.count;
    }
    return *this;
}


void
font_list::print()
    const
{
    for (int j = 0; j < size(); ++j)
        printf("%s\n", get(j));
}


font_list
font_list::operator+(const font_list &arg)
    const
{
    size_t len = count + arg.count;
    char **temp = new char * [len];
    for (int j = 0; j < count; ++j)
        temp[j] = list[j];
    for (int k = 0; k < arg.count; ++k)
        temp[k + count] = arg.list[k];
    font_list result((const char **)temp, len);
    delete [] temp;
    return result;
}
