//
// bigtext - print big text using X11 fonts
// Copyright (C) 2004, 2007, 2009 Peter Miller
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
//

#ifndef BIGTEXT_FONT_LIST_H
#define BIGTEXT_FONT_LIST_H

/**
  * The font_list class is used to represent a font list returned from a
  * font server.
  */
class font_list
{
public:
    /**
      * The destructor.
      */
    virtual ~font_list();

    /**
      * The constructor.
      */
    font_list(const char **, int);

    /**
      * The default constructor.  Do not use.
      */
    font_list();

    /**
      * The copy constructor.  Do not use.
      */
    font_list(const font_list &);

    /**
      * The assignment operator.  Do not use.
      */
    font_list &operator=(const font_list &);

    /**
      * The size method is used to determine the number of emelents in
      * the font list.
      */
    int
    size()
        const
    {
        return count;
    }

    /**
      * The get method is used to obtain the n'th element of the list,
      * counting from zsro.
      */
    const char *
    get(int n)
        const
    {
        if (n < 0 || n >= count)
            return 0;
        return list[n];
    }

    /**
      * The [] operator is used to obtain the n'th element of the list,
      * counting from zsro.
      */
    const char *
    operator[](int n)
        const
    {
        return get(n);
    }

    /**
      * The print method is used to print the font list on the standard output.
      */
    void print() const;

    font_list operator+(const font_list &arg) const;

private:
    /**
      * The list instance variable is used to remember the list of
      * fonts.
      *
      * The list of pointers to text, and the text inself, is all in a
      * single malloc()ed hunk of memory.  Thus, it can all be free()ed
      * with a single call.
      */
    char **list;

    /**
      * The list instance variable is used to remember the number of
      * fonts in the font list.
      */
    int count;
};

#endif // BIGTEXT_FONT_LIST_H
