//
//      bigtext - print big text using X11 fonts
//      Copyright (C) 2004, 2007, 2010 Peter Miller
//
//      This program is free software; you can redistribute it and/or modify
//      it under the terms of the GNU General Public License as published by
//      the Free Software Foundation; either version 3 of the License, or
//      (at your option) any later version.
//
//      This program is distributed in the hope that it will be useful,
//      but WITHOUT ANY WARRANTY; without even the implied warranty of
//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//      GNU General Public License for more details.
//
//      You should have received a copy of the GNU General Public License
//      along with this program. If not, see
//      <http://www.gnu.org/licenses/>.
//

#ifndef BIGTEXT_FONT_SERVER_H
#define BIGTEXT_FONT_SERVER_H

#include <bigtext/font_list.h>

class font; // forward

/**
  * The font_server class is an abstract interface to a font server.  It
  * could be an internal (hard coded) cont source, or an X11 Font Server
  * connection, or something else.
  */
class font_server
{
public:
    /**
      * The destructor.
      */
    virtual ~font_server();

    /**
      * The default constructor.
      */
    font_server();

    /**
      * The get_font_list method is used top obtain a list of fonts
      * available from the font server.
      */
    virtual font_list get_font_list(const char *pattern = 0) = 0;

    /**
      * The get_font method is used to obtain a font class instance
      * corresponding to the font name given.  If the font doesn't
      * exist, you will get an error later, when you try to draw a
      * character.
      *
      * \param name
      *     The name of the font to be fetched.  It includes the
      *     typeface name, the resolution and the point size.
      * \returns
      *     A pointer to an abstract font instance.
      *     It will return NULL if the font name cannot be found.
      */
    virtual font *get_font(const char *name) = 0;

private:
    /**
      * The copy constructor.  Do not use.
      */
    font_server(const font_server &);

    /**
      * The assignment operator.  Do not use.
      */
    font_server &operator=(const font_server &);
};

#endif // BIGTEXT_FONT_SERVER_H
