//
// bigtext - print big text using X11 fonts
// Copyright (C) 2004, 2007, 2009, 2010 Peter Miller
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
//

#include <cstddef>
#include <cstring>

#include <bigtext/font_server/internal.h>
#include <bigtext/font/internal/variable.h>
#include <bigtext/font/internal/fixed.h>

#undef SIZEOF
#define SIZEOF(a) (sizeof(a) / sizeof(a[0]))
#define ENDOF(a) ((a) + SIZEOF(a))

static font *new_variable() { return new font_internal_variable; }
static font *new_fixed() { return new font_internal_fixed; }

struct table_t
{
    const char *name;
    font *(*func)(void);
};

static table_t table[] =
{
    { "variable", new_variable },
    { "fixed", new_fixed },
};


font_server_internal::~font_server_internal()
{
}


font_server_internal::font_server_internal()
{
}


font_list
font_server_internal::get_font_list(const char *pattern)
{
    const char *temp[SIZEOF(table)];
    for (size_t j = 0; j < SIZEOF(table); ++j)
        temp[j] = table[j].name;
    return font_list(temp, SIZEOF(temp));
}


font *
font_server_internal::get_font(const char *name)
{
    for (table_t *tp = table; tp < ENDOF(table); ++tp)
    {
        if (0 == strcasecmp(tp->name, name))
            return tp->func();
    }
    return 0;
}
