//
//      bigtext - print big text using X11 fonts
//      Copyright (C) 2004, 2005, 2007, 2010 Peter Miller
//
//      This program is free software; you can redistribute it and/or modify
//      it under the terms of the GNU General Public License as published by
//      the Free Software Foundation; either version 3 of the License, or
//      (at your option) any later version.
//
//      This program is distributed in the hope that it will be useful,
//      but WITHOUT ANY WARRANTY; without even the implied warranty of
//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//      GNU General Public License for more details.
//
//      You should have received a copy of the GNU General Public License
//      along with this program. If not, see
//      <http://www.gnu.org/licenses/>.
//

#ifndef BIGTEXT_GLYPH_H
#define BIGTEXT_GLYPH_H

#include <X11/fonts/FSlib.h>

class canvas; // forward

/**
  * The glyph class is an abstract base class used to represent the
  * state of a glyph.  It can be used to show a glyph on a canvas.  It
  * knows the dimensions of the glyph and how to draw the bitmap of the
  * glyph.
  */
class glyph
{
public:
    /**
      * The destructor.
      */
    virtual ~glyph();

protected:
    /**
      * The default constructor.
      * It may only be called by derived classes.
      */
    glyph();

public:
    /**
      * The show method is used to show a glyph on a canvas.  The
      * lower left corner of the character will be placed at the given
      * location.
      */
    virtual void show(canvas &drawable, int x, int y, int pen) = 0;

    /**
      * The get_width method is used to obtain the width of the glyph.
      * This is the printing width of the character, the amount the
      * cursor should be advanced past the character.  It is not the
      * actual width of the glyph's bitmap bounding box.
      */
    virtual int get_width() = 0;

    /**
      * The print_internal_definition method is used to print suitable
      * code to convert a glyph into an internal glyph.
      */
    virtual int print_internal_definition() = 0;

    /**
      * The print_apple_pascal method is used to print a glyph suitable
      * for use with the ucsd-pascal-vm project.
      */
    void print_apple_pascal(int font_ascent, int font_descent);

private:
    /**
      * The copy constructor.  Do not use.
      */
    glyph(const glyph &);

    /**
      * The assignment operator.  Do not use.
      */
    glyph &operator=(const glyph &);
};

#endif // BIGTEXT_GLYPH_H
