//
//      bigtext - print big text using X11 fonts
//      Copyright (C) 2004, 2005, 2007, 2010 Peter Miller
//
//      This program is free software; you can redistribute it and/or modify
//      it under the terms of the GNU General Public License as published by
//      the Free Software Foundation; either version 3 of the License, or
//      (at your option) any later version.
//
//      This program is distributed in the hope that it will be useful,
//      but WITHOUT ANY WARRANTY; without even the implied warranty of
//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//      GNU General Public License for more details.
//
//      You should have received a copy of the GNU General Public License
//      along with this program. If not, see
//      <http://www.gnu.org/licenses/>.
//

#include <cstdio>

#include <bigtext/canvas.h>
#include <bigtext/glyph/internal.h>


glyph_internal::~glyph_internal()
{
}


glyph_internal::glyph_internal(const info_t &arg) :
    info(arg)
{
}


void
glyph_internal::show(canvas &drawable, int ox, int oy, int pen)
{
    const char *bp = info.bitmap;
    int row_span = ((info.right - info.left) + 7) / 8;
    for (int y = -info.ascent; y < info.descent; ++y)
    {
        for (int x = info.left; x < info.right; ++x)
        {
            unsigned xx = x - info.left;
            if (bp[xx >> 3] & (0x80 >> (xx & 7)))
                drawable.set(ox + x, oy + y, pen);
        }
        bp += row_span;
    }
}


int
glyph_internal::get_width()
{
    return info.width;
}


int
glyph_internal::print_internal_definition()
{
    printf("    {\n");
    printf("\t%d,\t// left bearing\n", info.left);
    printf("\t%d,\t// right bearing\n", info.right);
    printf("\t%d,\t// ascent\n", info.ascent);
    printf("\t%d,\t// descent\n", info.descent);
    printf("\t%d,\t// width\n", info.width + 1);
    int xdim = info.right - info.left;
    int ydim = info.ascent + info.descent;
    if (xdim > 0 && ydim > 0)
    {
        const char *bp = info.bitmap;
        int row_span = (xdim + 7) / 8;
        for (int y = 0; y < ydim; ++y)
        {
            printf("\t\"");
            for (int x = 0; x < row_span; ++x)
                printf("\\%03o", (unsigned char)*bp++);
            printf("\"\n");
        }
    }
    printf("    },\n");
    return 0;
}
