//
//      bigtext - print big text using X11 fonts
//      Copyright (C) 2004, 2005, 2007, 2010 Peter Miller
//
//      This program is free software; you can redistribute it and/or modify
//      it under the terms of the GNU General Public License as published by
//      the Free Software Foundation; either version 3 of the License, or
//      (at your option) any later version.
//
//      This program is distributed in the hope that it will be useful,
//      but WITHOUT ANY WARRANTY; without even the implied warranty of
//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//      GNU General Public License for more details.
//
//      You should have received a copy of the GNU General Public License
//      along with this program. If not, see
//      <http://www.gnu.org/licenses/>.
//

#ifndef BIGTEXT_GLYPH_INTERNAL_H
#define BIGTEXT_GLYPH_INTERNAL_H

#include <bigtext/glyph.h>

/**
  * The glyph_internal class is used to represent a glyph compiled into
  * the code.
  */
class glyph_internal:
    public glyph
{
public:
    /**
      * The destructor.
      */
    virtual ~glyph_internal();

    /**
      * The info_t structure is used to remember the bitmap data for the
      * glyph.
      */
    struct info_t
    {
        int left;
        int right;
        int ascent;
        int descent;
        int width;
        const char *bitmap;
    };

    /**
      * The constructor.
      */
    glyph_internal(const info_t &);

    // See base class for documentation.
    void show(canvas &drawable, int x, int y, int pen);

    // See base class for documentation.
    int get_width();

    // See base class for documentation.
    int print_internal_definition();

private:
    /**
      * The info instance variable is used to remmeber the data about
      * the glyph, including its geometry and bitmap.
      */
    const info_t &info;

    /**
      * The default constructor.  Do not use.
      */
    glyph_internal();

    /**
      * The copy constructor.  Do not use.
      */
    glyph_internal(const glyph_internal &);

    /**
      * The assignment operator.  Do not use.
      */
    glyph_internal &operator=(const glyph_internal &);
};

#endif // BIGTEXT_GLYPH_INTERNAL_H
