//
//      bigtext - print big text using X11 fonts
//      Copyright (C) 2006, 2007, 2010 Peter Miller
//
//      This program is free software; you can redistribute it and/or modify
//      it under the terms of the GNU General Public License as published by
//      the Free Software Foundation; either version 3 of the License, or
//      (at your option) any later version.
//
//      This program is distributed in the hope that it will be useful,
//      but WITHOUT ANY WARRANTY; without even the implied warranty of
//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//      GNU General Public License for more details.
//
//      You should have received a copy of the GNU General Public License
//      along with this program. If not, see
//      <http://www.gnu.org/licenses/>.
//

#include <cstdio>

#include <bigtext/glyph.h>
#include <bigtext/canvas/offset.h>
#include <bigtext/canvas/scale.h>
#include <bigtext/canvas/simple.h>


void
glyph::print_apple_pascal(int font_descent, int font_ascent)
{
    //
    // First we draw the glyph into a canvas,
    // greatly increasing it in size.
    //
    enum { factor = 4 };
    canvas_simple base;
    canvas_scale base_up(&base, factor, factor);
    canvas_offset base_up_o(&base_up, 0, font_ascent);
    show(base_up_o, 0, 0, '*');

    //
    // Now we build another canves which views the same underlying base,
    // but at a scale designed to map the character back to a 7x8 grid.
    //
    // This is why the size increase: it lets up do some antialiasing.
    // All the anti-aliasing is done by the canvas_scale instance.
    //
    canvas_scale base_7x8
    (
        &base,
        (get_width() <= 8 ? 1. : get_width() / 8.) * factor,
        (font_descent + font_ascent <= 8
            ? 1. : (font_descent + font_ascent) / 8.) * factor
    );

    //
    // Now pull out the data.
    //
    printf(" = {\n");
    for (int y = 0; y < 8; ++y)
    {
        printf("    \"");
        for (int x = 0; x < 8; ++x)
        {
            int c = base_7x8.get(x, y);
            putchar(c);
        }
        printf("\",\n");
    }
    printf("};\n");
}
