//
//      bigtext - print big text using X11 fonts
//      Copyright (C) 2004, 2005, 2007, 2010 Peter Miller
//
//      This program is free software; you can redistribute it and/or modify
//      it under the terms of the GNU General Public License as published by
//      the Free Software Foundation; either version 3 of the License, or
//      (at your option) any later version.
//
//      This program is distributed in the hope that it will be useful,
//      but WITHOUT ANY WARRANTY; without even the implied warranty of
//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//      GNU General Public License for more details.
//
//      You should have received a copy of the GNU General Public License
//      along with this program. If not, see
//      <http://www.gnu.org/licenses/>.
//

#include <cstdio>
#include <cctype>

#include <bigtext/canvas.h>
#include <bigtext/font/xfs.h>
#include <bigtext/glyph/xfs.h>


glyph_xfs::~glyph_xfs()
{
    if (bitmap)
    {
        FSFree((char *)bitmap);
        bitmap = 0;
    }
}


glyph_xfs::glyph_xfs(unsigned char arg1, font_xfs *arg2) :
    c(arg1),
    the_font(arg2),
    row_span(0),
    bitmap(0)
{
}


void
glyph_xfs::get_info()
{
    the_font->query_x_extents_8(c, &extent);
    row_span = (extent.right - extent.left + 7) >> 3;

    int xdim = extent.right - extent.left;
    int ydim = extent.ascent + extent.descent;

    if (xdim > 0 && ydim > 0)
        the_font->query_x_bitmaps_8(c, &bitmap);
    else
        bitmap = FSMalloc(1);
}


void
glyph_xfs::show(canvas &drawable, int ox, int oy, int pen)
{
    if (!bitmap)
        get_info();
    const unsigned char *bp = bitmap;
    for (int y = -extent.ascent; y < extent.descent; ++y)
    {
        for (int x = extent.left; x < extent.right; ++x)
        {
            unsigned xx = x - extent.left;
            if (bp[xx >> 3] & (0x80 >> (xx & 7)))
                drawable.set(ox + x, oy + y, pen);
        }
        bp += row_span;
    }
}


int
glyph_xfs::get_width()
{
    if (!bitmap)
        get_info();
    return extent.width + 1;
}


int
glyph_xfs::print_internal_definition()
{
    if (!bitmap)
        get_info();
    printf("    {\n");
    printf("\t\t// %02X", c);
    if (isprint(c))
        printf(" '%c'", c);
    printf("\n");
    printf("\t%d,\t// left bearing\n", extent.left);
    printf("\t%d,\t// right bearing\n", extent.right);
    printf("\t%d,\t// ascent\n", extent.ascent);
    printf("\t%d,\t// descent\n", extent.descent);
    printf("\t%d,\t// width\n", extent.width + 1);
    int xdim = extent.right - extent.left;
    int ydim = extent.ascent + extent.descent;
    if (xdim > 0 && ydim > 0)
    {
        int row_span = ((xdim + 7) / 8);
        unsigned char *bp = bitmap;
        for (int y = 0; y < ydim; ++y)
        {
            printf("\t\"");
            for (int x = 0; x < row_span; ++x)
                printf("\\%03o", *bp++);
            printf("\"\n");
        }
    }
    printf("    },\n");
    return 0;
}
