//
//      bigtext - print big text using X11 fonts
//      Copyright (C) 2004, 2005, 2007, 2010 Peter Miller
//
//      This program is free software; you can redistribute it and/or modify
//      it under the terms of the GNU General Public License as published by
//      the Free Software Foundation; either version 3 of the License, or
//      (at your option) any later version.
//
//      This program is distributed in the hope that it will be useful,
//      but WITHOUT ANY WARRANTY; without even the implied warranty of
//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//      GNU General Public License for more details.
//
//      You should have received a copy of the GNU General Public License
//      along with this program. If not, see
//      <http://www.gnu.org/licenses/>.
//

#ifndef BIGTEXT_GLYPH_XFS_H
#define BIGTEXT_GLYPH_XFS_H

#include <bigtext/glyph.h>

class font_xfs;

/**
  * The glyph_xfs class is used to represent the state of a glyph
  * obtaind from a X11 Font Server.
  */
class glyph_xfs:
    public glyph
{
public:
    /**
      * The destructor.
      */
    virtual ~glyph_xfs();

    /**
      * The constructor.
      */
    glyph_xfs(unsigned char arg1, font_xfs *arg2);

    // See base class for documentation.
    void show(canvas &drawable, int x, int y, int pen);

    // See base class for documentation.
    int get_width();

    // See base class for documentation.
    int print_internal_definition();

private:
    /**
      * The c instance variable is used to remember the value of the
      * character this glyph_xfs corresponds to.  Needed for making requests
      * to the font.
      */
    unsigned char c;

    /**
      * The the_font instance variable is used to remember the font this
      * glyph_xfs is part of.
      */
    font_xfs *the_font;

    /**
      * The row_span instance variable is used to remember the number
      * of bytes in the bitmap for each row of the glyph_xfs.  Used by the
      * show() method.
      */
    unsigned row_span;

    /**
      * The extent instance variable is used to remember information
      * about the glyph_xfs's geometry.
      */
    FSXCharInfo extent;

    /**
      * The bitmap instance variable is used to remember the bitmap of
      * this glyph_xfs.  All the rows are run together into a single array.
      * Use FSFree when you are done with it, NOT the delete operator.
      */
    unsigned char *bitmap;

    /**
      * The get_info method is used to obtain the information and bitmap
      * of this character from the font.
      */
    void get_info();

    /**
      * The default constructor.  Do not use.
      */
    glyph_xfs();

    /**
      * The copy constructor.  Do not use.
      */
    glyph_xfs(const glyph_xfs &);

    /**
      * The assignment operator.  Do not use.
      */
    glyph_xfs &operator=(const glyph_xfs &);
};

#endif // BIGTEXT_GLYPH_XFS_H
