//
//      bigtext - print big text using X11 fonts
//      Copyright (C) 2004, 2005, 2007, 2010 Peter Miller
//
//      This program is free software; you can redistribute it and/or modify
//      it under the terms of the GNU General Public License as published by
//      the Free Software Foundation; either version 3 of the License, or
//      (at your option) any later version.
//
//      This program is distributed in the hope that it will be useful,
//      but WITHOUT ANY WARRANTY; without even the implied warranty of
//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//      GNU General Public License for more details.
//
//      You should have received a copy of the GNU General Public License
//      along with this program. If not, see
//      <http://www.gnu.org/licenses/>.
//

#include <cctype>
#include <cstdio>
#include <cstdlib>

#include <bigtext/glyph.h>
#include <bigtext/graphics_context.h>
#include <bigtext/font.h>
#include <bigtext/font_server.h>


graphics_context::~graphics_context()
{
    if (the_font)
    {
        delete the_font;
        the_font = 0;
    }
}


graphics_context::graphics_context(canvas &arg1, font_server &arg2) :
    drawable(arg1),
    server(arg2),
    the_font(0),
    cursor_x(0),
    cursor_y(0),
    pen(0)
{
}


void
graphics_context::set_self_char()
{
    pen = -1;
}


void
graphics_context::set_pen(int c)
{
    pen = (c < 0 || !isprint((unsigned char)c)) ? 0 : c;
}


void
graphics_context::set_font(const char *name)
{
    if (the_font)
    {
        delete the_font;
        the_font = 0;
    }
    if (name)
    {
        the_font = server.get_font(name);
        if (!the_font)
        {
            fprintf(stderr, "font name \"%s\" unknown\n", name);
            exit(1);
        }
    }
}


void
graphics_context::show(const char *s)
{
    if (!s)
        return;
    if (!the_font)
        set_font("variable");
    while (*s)
    {
        unsigned char c = *s++;
        if (c == '\n')
        {
            cursor_x = 0;
            cursor_y += the_font->get_ascent() + the_font->get_descent();
            continue;
        }
        glyph *gp = the_font->get_glyph(c);
        gp->show
        (
            drawable,
            cursor_x,
            cursor_y - the_font->get_ascent(),
            (pen < 0 ? c : pen)
        );
        cursor_x += gp->get_width();
    }
}
