//
// bigtext - print big text using X11 fonts
// Copyright (C) 2004, 2005, 2007, 2010, 2012 Peter Miller
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
//

#include <lib/config.h>
#include <libexplain/fflush.h>
#include <libexplain/freopen.h>

#include <bigtext/arglex/bigtext.h>
#include <bigtext/canvas/rotate.h>
#include <bigtext/canvas/simple.h>
#include <bigtext/font.h>
#include <bigtext/font_server/compound.h>
#include <bigtext/graphics_context.h>


int
main(int argc, char **argv)
{
    arglex_bigtext cmdline(argc, argv);
    font_server_compound fs;
    switch (cmdline.token_first())
    {
    case arglex_bigtext::token_output:
        {
            if (cmdline.token_next() != arglex::token_string)
                cmdline.usage();
            explain_freopen_or_die(cmdline.value_string(), "w", stdout);
        }
        break;

    case arglex_bigtext::token_list:
        {
            font_list fl = fs.get_font_list();
            fl.print();
            explain_fflush_or_die(stdout);
        }
        return 0;

    case arglex_bigtext::token_apple_pascal:
        {
            if (cmdline.token_next_string() != arglex_bigtext::token_string)
                cmdline.usage();
            font *fp = fs.get_font(cmdline.value_string());
            fp->print_apple_pascal();
            explain_fflush_or_die(stdout);
        }
        return 0;

    case arglex_bigtext::token_internal_code:
        {
            if (cmdline.token_next_string() != arglex_bigtext::token_string)
                cmdline.usage();
            font *fp = fs.get_font(cmdline.value_string());
            fp->print_internal_code();
            explain_fflush_or_die(stdout);
        }
        return 0;

    case arglex_bigtext::token_internal_header:
        {
            if (cmdline.token_next_string() != arglex_bigtext::token_string)
                cmdline.usage();
            font *fp = fs.get_font(cmdline.value_string());
            fp->print_internal_header();
            explain_fflush_or_die(stdout);
        }
        return 0;
    }

    canvas_simple drawing;
    graphics_context gc(drawing, fs);
    canvas_rotate rdrawing(&drawing);
    graphics_context rgc(rdrawing, fs);
    graphics_context *gc_p = &gc;
    while (cmdline.token_cur() != arglex::token_eoln)
    {
        switch (cmdline.token_cur())
        {
        default:
            cmdline.bad_argument();
            // NOTREACHED

        case arglex_bigtext::token_self_char:
            gc_p->set_self_char();
            break;

        case arglex_bigtext::token_font:
            if (cmdline.token_next_string() != arglex::token_string)
                cmdline.usage();
            gc_p->set_font(cmdline.value_string());
            break;

        case arglex::token_string:
            gc_p->show(cmdline.value_string());
            gc_p->show(" ");
            break;

        case arglex_bigtext::token_rotate:
            gc_p = (gc_p == &gc ? &rgc : &gc);
            break;
        }
        cmdline.token_next();
    }
    drawing.print();
    explain_fflush_or_die(stdout);
    return 0;
}

// vim: set ts=8 sw=4 et :
